json = {
    "components": [
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Radius",
                    "name": "radius",
                    "tooltip": "Central arc radius.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Angle",
                    "name": "angle",
                    "tooltip": "Arc coverage angle.",
                    "defaults": 90.0,
                    "type": "number",
                    "suffix": "°",
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [-90], "max": [90]},
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bend that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "type": "number",
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.bend",
            "label": "Bend",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-0.462500 -8.462500 10.175000 10.175000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.050875;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.050875;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.050875;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.050875;}.reference{fill:none;stroke:#221f20;stroke-width:0.035612;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.407000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.050875;}.dashed{stroke-dasharray:0.254375,0.152625;}.port{fill:none;stroke:#805080;stroke-width:0.101750;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.076313;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.203500 L 0.305250,0 0,0.203500" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.152625 C 0.203500,-0.152625 0.203500,0.152625 0,0.152625" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.106838" /></defs><g transform="scale(1 -1)"><g id="bend-0x56b8e592a460"><path class="layer_1_0" d="M 0.000000,-1.250000 0.346000,-1.244000 0.691000,-1.224000 1.036000,-1.192000 1.379000,-1.147000 1.720000,-1.089000 2.058000,-1.018000 2.394000,-0.935000 2.726000,-0.839000 3.055000,-0.731000 3.379000,-0.611000 3.699000,-0.478000 4.013000,-0.334000 4.322000,-0.178000 4.625000,-0.011000 4.921000,0.168000 5.211000,0.357000 5.493000,0.557000 5.767000,0.768000 6.034000,0.989000 6.292000,1.219000 6.541000,1.459000 6.781000,1.708000 7.011000,1.966000 7.232000,2.233000 7.443000,2.507000 7.643000,2.789000 7.832000,3.079000 8.011000,3.375000 8.178000,3.678000 8.334000,3.987000 8.478000,4.301000 8.611000,4.621000 8.731000,4.945000 8.839000,5.274000 8.935000,5.606000 9.018000,5.942000 9.089000,6.280000 9.147000,6.621000 9.192000,6.964000 9.224000,7.309000 9.244000,7.654000 9.250000,8.000000 6.750000,8.000000 6.745000,7.748000 6.708000,7.244000 6.675000,6.994000 6.581000,6.498000 6.450000,6.010000 6.283000,5.534000 6.082000,5.071000 5.846000,4.625000 5.577000,4.198000 5.277000,3.791000 4.948000,3.409000 4.591000,3.052000 4.209000,2.723000 3.802000,2.423000 3.375000,2.154000 2.929000,1.918000 2.466000,1.717000 1.990000,1.550000 1.502000,1.419000 1.006000,1.325000 0.756000,1.292000 0.504000,1.269000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 0.308000,-0.244000 0.617000,-0.227000 0.924000,-0.198000 1.230000,-0.158000 1.534000,-0.106000 1.836000,-0.043000 2.135000,0.031000 2.432000,0.117000 2.725000,0.213000 3.014000,0.320000 3.299000,0.438000 3.580000,0.567000 3.855000,0.706000 4.125000,0.855000 4.389000,1.015000 4.647000,1.184000 4.899000,1.362000 5.144000,1.550000 5.381000,1.747000 5.611000,1.952000 5.834000,2.166000 6.048000,2.389000 6.253000,2.619000 6.450000,2.856000 6.638000,3.101000 6.816000,3.353000 6.985000,3.611000 7.145000,3.875000 7.294000,4.145000 7.433000,4.420000 7.562000,4.701000 7.680000,4.986000 7.787000,5.275000 7.883000,5.568000 7.969000,5.865000 8.043000,6.164000 8.106000,6.466000 8.158000,6.770000 8.198000,7.076000 8.227000,7.383000 8.244000,7.692000 8.250000,8.000000 7.750000,8.000000 7.745000,7.710000 7.728000,7.421000 7.701000,7.132000 7.663000,6.845000 7.615000,6.559000 7.556000,6.275000 7.486000,5.994000 7.406000,5.716000 7.315000,5.440000 7.214000,5.169000 6.983000,4.637000 6.712000,4.125000 6.562000,3.877000 6.403000,3.634000 6.236000,3.398000 6.059000,3.168000 5.874000,2.945000 5.681000,2.729000 5.480000,2.520000 5.271000,2.319000 5.055000,2.126000 4.832000,1.941000 4.602000,1.764000 4.366000,1.597000 4.123000,1.438000 3.875000,1.288000 3.363000,1.017000 2.831000,0.786000 2.560000,0.685000 2.284000,0.594000 2.006000,0.514000 1.725000,0.444000 1.441000,0.385000 1.155000,0.337000 0.868000,0.299000 0.290000,0.255000 0.000000,0.250000 z" /><g transform="translate(8.000000 8.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Arm Length",
                    "name": "arm_length",
                    "tooltip": "Length of a single crossing arm.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Added Width",
                    "name": "added_width",
                    "tooltip": 'Width added to the arm linearly up to the center. An expression or string (with independent variable ``"u"``) can also be used.',
                    "defaults": 0.0,
                    "type": "input",
                    "validates": ["expression"],
                    "validatesArgs": {"expression": [1]},
                    "suffix": "μm",
                },
                {
                    "label": "Extra Length",
                    "name": "extra_length",
                    "tooltip": "Additional length for a straight section at the ports.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.crossing",
            "label": "Crossing",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-5.500000 -5.500000 11.000000 11.000000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.055000;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.055000;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.055000;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.055000;}.reference{fill:none;stroke:#221f20;stroke-width:0.038500;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.440000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.055000;}.dashed{stroke-dasharray:0.275000,0.165000;}.port{fill:none;stroke:#805080;stroke-width:0.110000;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.082500;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.220000 L 0.330000,0 0,0.220000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.165000 C 0.220000,-0.165000 0.220000,0.165000 0,0.165000" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.115500" /></defs><g transform="scale(1 -1)"><g id="crossing-0x56b8e5d83070"><path class="layer_1_0" d="M 4.000000,1.290000 3.000000,1.330000 2.000000,1.370000 1.394000,1.394000 1.370000,2.000000 1.330000,3.000000 1.290000,4.000000 1.250000,5.000000 -1.250000,5.000000 -1.290000,4.000000 -1.330000,3.000000 -1.370000,2.000000 -1.394000,1.394000 -2.000000,1.370000 -3.000000,1.330000 -4.000000,1.290000 -5.000000,1.250000 -5.000000,-1.250000 -4.000000,-1.290000 -3.000000,-1.330000 -2.000000,-1.370000 -1.394000,-1.394000 -1.370000,-2.000000 -1.330000,-3.000000 -1.290000,-4.000000 -1.250000,-5.000000 1.250000,-5.000000 1.290000,-4.000000 1.330000,-3.000000 1.370000,-2.000000 1.394000,-1.394000 2.000000,-1.370000 3.000000,-1.330000 4.000000,-1.290000 5.000000,-1.250000 5.000000,1.250000 z" /><path class="layer_2_0" d="M 4.000000,0.290000 3.000000,0.330000 2.000000,0.370000 1.000000,0.410000 0.433000,0.433000 0.410000,1.000000 0.370000,2.000000 0.330000,3.000000 0.290000,4.000000 0.250000,5.000000 -0.250000,5.000000 -0.290000,4.000000 -0.330000,3.000000 -0.370000,2.000000 -0.410000,1.000000 -0.433000,0.433000 -1.000000,0.410000 -2.000000,0.370000 -3.000000,0.330000 -4.000000,0.290000 -5.000000,0.250000 -5.000000,-0.250000 -4.000000,-0.290000 -3.000000,-0.330000 -2.000000,-0.370000 -1.000000,-0.410000 -0.433000,-0.433000 -0.410000,-1.000000 -0.370000,-2.000000 -0.330000,-3.000000 -0.290000,-4.000000 -0.250000,-5.000000 0.250000,-5.000000 0.290000,-4.000000 0.330000,-3.000000 0.370000,-2.000000 0.410000,-1.000000 0.433000,-0.433000 1.000000,-0.410000 2.000000,-0.370000 3.000000,-0.330000 4.000000,-0.290000 5.000000,-0.250000 5.000000,0.250000 z" /><g transform="translate(0.000000 5.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(5.000000 0.000000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 -5.000000) rotate(90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-5.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section. A tuple with 2 values can be used, one for each coupler side.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Coupling Distance",
                    "name": "coupling_distance",
                    "tooltip": "Distance between bus and ring waveguide centers.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Radius",
                    "name": "radius",
                    "tooltip": "Central ring radius.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bends that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "type": "number",
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                },
                {
                    "label": "Coupling Length",
                    "name": "coupling_length",
                    "tooltip": "Length of straigh coupling region.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.dual_ring_coupler",
            "label": "Dual Ring Coupler",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-10.175000 -0.925000 20.350000 18.500000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.092500;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.092500;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.092500;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.092500;}.reference{fill:none;stroke:#221f20;stroke-width:0.064750;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.740000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.092500;}.dashed{stroke-dasharray:0.462500,0.277500;}.port{fill:none;stroke:#805080;stroke-width:0.185000;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.138750;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.370000 L 0.555000,0 0,0.370000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.277500 C 0.370000,-0.277500 0.370000,0.277500 0,0.277500" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.194250" /></defs><g transform="scale(1 -1)"><g id="dual_ring_coupler-0x56b8e5dca0a0"><path class="layer_1_0" d="M -6.750000,-16.650000 -6.731000,-16.146000 -6.708000,-15.894000 -6.675000,-15.644000 -6.581000,-15.148000 -6.450000,-14.660000 -6.283000,-14.184000 -6.082000,-13.721000 -5.846000,-13.275000 -5.577000,-12.848000 -5.277000,-12.441000 -4.948000,-12.059000 -4.591000,-11.702000 -4.209000,-11.373000 -3.802000,-11.073000 -3.375000,-10.804000 -2.929000,-10.568000 -2.466000,-10.367000 -1.990000,-10.200000 -1.502000,-10.069000 -1.006000,-9.975000 -0.756000,-9.942000 -0.252000,-9.905000 0.000000,-9.900000 0.504000,-9.919000 0.756000,-9.942000 1.006000,-9.975000 1.502000,-10.069000 1.990000,-10.200000 2.466000,-10.367000 2.929000,-10.568000 3.375000,-10.804000 3.802000,-11.073000 4.209000,-11.373000 4.591000,-11.702000 4.948000,-12.059000 5.277000,-12.441000 5.577000,-12.848000 5.846000,-13.275000 6.082000,-13.721000 6.283000,-14.184000 6.450000,-14.660000 6.581000,-15.148000 6.675000,-15.644000 6.708000,-15.894000 6.745000,-16.398000 6.750000,-16.650000 9.250000,-16.650000 9.244000,-16.304000 9.224000,-15.959000 9.192000,-15.614000 9.147000,-15.271000 9.089000,-14.930000 9.018000,-14.592000 8.935000,-14.256000 8.839000,-13.924000 8.731000,-13.595000 8.611000,-13.271000 8.478000,-12.951000 8.334000,-12.637000 8.178000,-12.328000 8.011000,-12.025000 7.832000,-11.729000 7.643000,-11.439000 7.443000,-11.157000 7.232000,-10.883000 7.011000,-10.616000 6.781000,-10.358000 6.541000,-10.109000 6.292000,-9.869000 6.034000,-9.639000 5.767000,-9.418000 5.493000,-9.207000 5.211000,-9.007000 4.921000,-8.818000 4.625000,-8.639000 4.322000,-8.472000 4.013000,-8.316000 3.699000,-8.172000 3.379000,-8.039000 3.055000,-7.919000 2.726000,-7.811000 2.394000,-7.715000 2.058000,-7.632000 1.720000,-7.561000 1.379000,-7.503000 1.036000,-7.458000 0.691000,-7.426000 0.346000,-7.406000 0.000000,-7.400000 -0.346000,-7.406000 -0.691000,-7.426000 -1.036000,-7.458000 -1.379000,-7.503000 -1.720000,-7.561000 -2.058000,-7.632000 -2.394000,-7.715000 -2.726000,-7.811000 -3.055000,-7.919000 -3.379000,-8.039000 -3.699000,-8.172000 -4.013000,-8.316000 -4.322000,-8.472000 -4.625000,-8.639000 -4.921000,-8.818000 -5.211000,-9.007000 -5.493000,-9.207000 -5.767000,-9.418000 -6.034000,-9.639000 -6.292000,-9.869000 -6.541000,-10.109000 -6.781000,-10.358000 -7.011000,-10.616000 -7.232000,-10.883000 -7.443000,-11.157000 -7.643000,-11.439000 -7.832000,-11.729000 -8.011000,-12.025000 -8.178000,-12.328000 -8.334000,-12.637000 -8.478000,-12.951000 -8.611000,-13.271000 -8.731000,-13.595000 -8.839000,-13.924000 -8.935000,-14.256000 -9.018000,-14.592000 -9.089000,-14.930000 -9.147000,-15.271000 -9.192000,-15.614000 -9.224000,-15.959000 -9.244000,-16.304000 -9.250000,-16.650000 z" /><path class="layer_1_0" d="M 6.750000,0.000000 6.731000,-0.504000 6.708000,-0.756000 6.675000,-1.006000 6.581000,-1.502000 6.450000,-1.990000 6.283000,-2.466000 6.082000,-2.929000 5.846000,-3.375000 5.577000,-3.802000 5.277000,-4.209000 4.948000,-4.591000 4.591000,-4.948000 4.209000,-5.277000 3.802000,-5.577000 3.375000,-5.846000 2.929000,-6.082000 2.466000,-6.283000 1.990000,-6.450000 1.502000,-6.581000 1.006000,-6.675000 0.756000,-6.708000 0.252000,-6.745000 0.000000,-6.750000 -0.504000,-6.731000 -0.756000,-6.708000 -1.006000,-6.675000 -1.502000,-6.581000 -1.990000,-6.450000 -2.466000,-6.283000 -2.929000,-6.082000 -3.375000,-5.846000 -3.802000,-5.577000 -4.209000,-5.277000 -4.591000,-4.948000 -4.948000,-4.591000 -5.277000,-4.209000 -5.577000,-3.802000 -5.846000,-3.375000 -6.082000,-2.929000 -6.283000,-2.466000 -6.450000,-1.990000 -6.581000,-1.502000 -6.675000,-1.006000 -6.708000,-0.756000 -6.745000,-0.252000 -6.750000,0.000000 -9.250000,0.000000 -9.244000,-0.346000 -9.224000,-0.691000 -9.192000,-1.036000 -9.147000,-1.379000 -9.089000,-1.720000 -9.018000,-2.058000 -8.935000,-2.394000 -8.839000,-2.726000 -8.731000,-3.055000 -8.611000,-3.379000 -8.478000,-3.699000 -8.334000,-4.013000 -8.178000,-4.322000 -8.011000,-4.625000 -7.832000,-4.921000 -7.643000,-5.211000 -7.443000,-5.493000 -7.232000,-5.767000 -7.011000,-6.034000 -6.781000,-6.292000 -6.541000,-6.541000 -6.292000,-6.781000 -6.034000,-7.011000 -5.767000,-7.232000 -5.493000,-7.443000 -5.211000,-7.643000 -4.921000,-7.832000 -4.625000,-8.011000 -4.322000,-8.178000 -4.013000,-8.334000 -3.699000,-8.478000 -3.379000,-8.611000 -3.055000,-8.731000 -2.726000,-8.839000 -2.394000,-8.935000 -2.058000,-9.018000 -1.720000,-9.089000 -1.379000,-9.147000 -1.036000,-9.192000 -0.691000,-9.224000 -0.346000,-9.244000 0.000000,-9.250000 0.346000,-9.244000 0.691000,-9.224000 1.036000,-9.192000 1.379000,-9.147000 1.720000,-9.089000 2.058000,-9.018000 2.394000,-8.935000 2.726000,-8.839000 3.055000,-8.731000 3.379000,-8.611000 3.699000,-8.478000 4.013000,-8.334000 4.322000,-8.178000 4.625000,-8.011000 4.921000,-7.832000 5.211000,-7.643000 5.493000,-7.443000 5.767000,-7.232000 6.034000,-7.011000 6.292000,-6.781000 6.541000,-6.541000 6.781000,-6.292000 7.011000,-6.034000 7.232000,-5.767000 7.443000,-5.493000 7.643000,-5.211000 7.832000,-4.921000 8.011000,-4.625000 8.178000,-4.322000 8.334000,-4.013000 8.478000,-3.699000 8.611000,-3.379000 8.731000,-3.055000 8.839000,-2.726000 8.935000,-2.394000 9.018000,-2.058000 9.089000,-1.720000 9.147000,-1.379000 9.192000,-1.036000 9.224000,-0.691000 9.244000,-0.346000 9.250000,0.000000 z" /><path class="layer_2_0" d="M -7.750000,-16.650000 -7.745000,-16.360000 -7.701000,-15.782000 -7.663000,-15.495000 -7.615000,-15.209000 -7.556000,-14.925000 -7.486000,-14.644000 -7.406000,-14.366000 -7.315000,-14.090000 -7.214000,-13.819000 -6.983000,-13.287000 -6.712000,-12.775000 -6.562000,-12.527000 -6.403000,-12.284000 -6.236000,-12.048000 -6.059000,-11.818000 -5.874000,-11.595000 -5.681000,-11.379000 -5.480000,-11.170000 -5.271000,-10.969000 -5.055000,-10.776000 -4.832000,-10.591000 -4.602000,-10.414000 -4.366000,-10.247000 -4.123000,-10.088000 -3.875000,-9.938000 -3.363000,-9.667000 -2.831000,-9.436000 -2.560000,-9.335000 -2.284000,-9.244000 -2.006000,-9.164000 -1.725000,-9.094000 -1.441000,-9.035000 -1.155000,-8.987000 -0.868000,-8.949000 -0.579000,-8.922000 -0.290000,-8.905000 0.000000,-8.900000 0.290000,-8.905000 0.868000,-8.949000 1.155000,-8.987000 1.441000,-9.035000 1.725000,-9.094000 2.006000,-9.164000 2.284000,-9.244000 2.560000,-9.335000 2.831000,-9.436000 3.363000,-9.667000 3.875000,-9.938000 4.123000,-10.088000 4.366000,-10.247000 4.602000,-10.414000 4.832000,-10.591000 5.055000,-10.776000 5.271000,-10.969000 5.480000,-11.170000 5.681000,-11.379000 5.874000,-11.595000 6.059000,-11.818000 6.236000,-12.048000 6.403000,-12.284000 6.562000,-12.527000 6.712000,-12.775000 6.983000,-13.287000 7.214000,-13.819000 7.315000,-14.090000 7.406000,-14.366000 7.486000,-14.644000 7.556000,-14.925000 7.615000,-15.209000 7.663000,-15.495000 7.701000,-15.782000 7.728000,-16.071000 7.745000,-16.360000 7.750000,-16.650000 8.250000,-16.650000 8.244000,-16.342000 8.227000,-16.033000 8.198000,-15.726000 8.158000,-15.420000 8.106000,-15.116000 8.043000,-14.814000 7.969000,-14.515000 7.883000,-14.218000 7.787000,-13.925000 7.680000,-13.636000 7.562000,-13.351000 7.433000,-13.070000 7.294000,-12.795000 7.145000,-12.525000 6.985000,-12.261000 6.816000,-12.003000 6.638000,-11.751000 6.450000,-11.506000 6.253000,-11.269000 6.048000,-11.039000 5.834000,-10.816000 5.611000,-10.602000 5.381000,-10.397000 5.144000,-10.200000 4.899000,-10.012000 4.647000,-9.834000 4.389000,-9.665000 4.125000,-9.505000 3.855000,-9.356000 3.580000,-9.217000 3.299000,-9.088000 3.014000,-8.970000 2.725000,-8.863000 2.432000,-8.767000 2.135000,-8.681000 1.836000,-8.607000 1.534000,-8.544000 1.230000,-8.492000 0.924000,-8.452000 0.617000,-8.423000 0.308000,-8.406000 0.000000,-8.400000 -0.308000,-8.406000 -0.617000,-8.423000 -0.924000,-8.452000 -1.230000,-8.492000 -1.534000,-8.544000 -1.836000,-8.607000 -2.135000,-8.681000 -2.432000,-8.767000 -2.725000,-8.863000 -3.014000,-8.970000 -3.299000,-9.088000 -3.580000,-9.217000 -3.855000,-9.356000 -4.125000,-9.505000 -4.389000,-9.665000 -4.647000,-9.834000 -4.899000,-10.012000 -5.144000,-10.200000 -5.381000,-10.397000 -5.611000,-10.602000 -5.834000,-10.816000 -6.048000,-11.039000 -6.253000,-11.269000 -6.450000,-11.506000 -6.638000,-11.751000 -6.816000,-12.003000 -6.985000,-12.261000 -7.145000,-12.525000 -7.294000,-12.795000 -7.433000,-13.070000 -7.562000,-13.351000 -7.680000,-13.636000 -7.787000,-13.925000 -7.883000,-14.218000 -7.969000,-14.515000 -8.043000,-14.814000 -8.106000,-15.116000 -8.158000,-15.420000 -8.198000,-15.726000 -8.227000,-16.033000 -8.244000,-16.342000 -8.250000,-16.650000 z" /><path class="layer_2_0" d="M 7.750000,0.000000 7.745000,-0.290000 7.701000,-0.868000 7.663000,-1.155000 7.615000,-1.441000 7.556000,-1.725000 7.486000,-2.006000 7.406000,-2.284000 7.315000,-2.560000 7.214000,-2.831000 6.983000,-3.363000 6.712000,-3.875000 6.562000,-4.123000 6.403000,-4.366000 6.236000,-4.602000 6.059000,-4.832000 5.874000,-5.055000 5.681000,-5.271000 5.480000,-5.480000 5.271000,-5.681000 5.055000,-5.874000 4.832000,-6.059000 4.602000,-6.236000 4.366000,-6.403000 4.123000,-6.562000 3.875000,-6.712000 3.363000,-6.983000 2.831000,-7.214000 2.560000,-7.315000 2.284000,-7.406000 2.006000,-7.486000 1.725000,-7.556000 1.441000,-7.615000 1.155000,-7.663000 0.868000,-7.701000 0.579000,-7.728000 0.290000,-7.745000 0.000000,-7.750000 -0.290000,-7.745000 -0.868000,-7.701000 -1.155000,-7.663000 -1.441000,-7.615000 -1.725000,-7.556000 -2.006000,-7.486000 -2.284000,-7.406000 -2.560000,-7.315000 -2.831000,-7.214000 -3.363000,-6.983000 -3.875000,-6.712000 -4.123000,-6.562000 -4.366000,-6.403000 -4.602000,-6.236000 -4.832000,-6.059000 -5.055000,-5.874000 -5.271000,-5.681000 -5.480000,-5.480000 -5.681000,-5.271000 -5.874000,-5.055000 -6.059000,-4.832000 -6.236000,-4.602000 -6.403000,-4.366000 -6.562000,-4.123000 -6.712000,-3.875000 -6.983000,-3.363000 -7.214000,-2.831000 -7.315000,-2.560000 -7.406000,-2.284000 -7.486000,-2.006000 -7.556000,-1.725000 -7.615000,-1.441000 -7.663000,-1.155000 -7.701000,-0.868000 -7.728000,-0.579000 -7.745000,-0.290000 -7.750000,0.000000 -8.250000,0.000000 -8.244000,-0.308000 -8.227000,-0.617000 -8.198000,-0.924000 -8.158000,-1.230000 -8.106000,-1.534000 -8.043000,-1.836000 -7.969000,-2.135000 -7.883000,-2.432000 -7.787000,-2.725000 -7.680000,-3.014000 -7.562000,-3.299000 -7.433000,-3.580000 -7.294000,-3.855000 -7.145000,-4.125000 -6.985000,-4.389000 -6.816000,-4.647000 -6.638000,-4.899000 -6.450000,-5.144000 -6.253000,-5.381000 -6.048000,-5.611000 -5.834000,-5.834000 -5.611000,-6.048000 -5.381000,-6.253000 -5.144000,-6.450000 -4.899000,-6.638000 -4.647000,-6.816000 -4.389000,-6.985000 -4.125000,-7.145000 -3.855000,-7.294000 -3.580000,-7.433000 -3.299000,-7.562000 -3.014000,-7.680000 -2.725000,-7.787000 -2.432000,-7.883000 -2.135000,-7.969000 -1.836000,-8.043000 -1.534000,-8.106000 -1.230000,-8.158000 -0.924000,-8.198000 -0.617000,-8.227000 -0.308000,-8.244000 0.000000,-8.250000 0.308000,-8.244000 0.617000,-8.227000 0.924000,-8.198000 1.230000,-8.158000 1.534000,-8.106000 1.836000,-8.043000 2.135000,-7.969000 2.432000,-7.883000 2.725000,-7.787000 3.014000,-7.680000 3.299000,-7.562000 3.580000,-7.433000 3.855000,-7.294000 4.125000,-7.145000 4.389000,-6.985000 4.647000,-6.816000 4.899000,-6.638000 5.144000,-6.450000 5.381000,-6.253000 5.611000,-6.048000 5.834000,-5.834000 6.048000,-5.611000 6.253000,-5.381000 6.450000,-5.144000 6.638000,-4.899000 6.816000,-4.647000 6.985000,-4.389000 7.145000,-4.125000 7.294000,-3.855000 7.433000,-3.580000 7.562000,-3.299000 7.680000,-3.014000 7.787000,-2.725000 7.883000,-2.432000 7.969000,-2.135000 8.043000,-1.836000 8.106000,-1.534000 8.158000,-1.230000 8.198000,-0.924000 8.227000,-0.617000 8.244000,-0.308000 8.250000,0.000000 z" /><g transform="translate(8.000000 0.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(8.000000 -16.650000) rotate(90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-8.000000 0.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-8.000000 -16.650000) rotate(90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Turns",
                    "name": "turns",
                    "tooltip": "Number of turns in each of the 2 spiral arms.",
                    "type": "number",
                    "validates": ["min", "integer"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Radius",
                    "name": "radius",
                    "tooltip": "Bend radius for the spiral turns.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Separation",
                    "name": "separation",
                    "tooltip": "Distance between waveguide centers in parallel sections.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "children": [
                        {
                            "hideLabel": True,
                            "name": "x",
                            "prefix": "x",
                            "suffix": "μm",
                            "type": "number",
                            "validates": ["min"],
                            "validatesArgs": {"min": [0]},
                        },
                        {
                            "hideLabel": True,
                            "name": "y",
                            "prefix": "y",
                            "suffix": "μm",
                            "type": "number",
                            "validates": ["min"],
                            "validatesArgs": {"min": [0]},
                        },
                    ],
                    "itemSpan": 12,
                    "label": "Size",
                    "name": "size",
                    "tooltip": "Spiral dimensions measured from the waveguide centers.",
                    "category": "tuple",
                    "type": "subForm",
                },
                {
                    "label": "Align Ports",
                    "name": "align_ports",
                    "tooltip": 'Optionally align ports to have centers with same ``"x"`` or ``"y"`` coordinates.',
                    "defaults": "",
                    "options": ["", "x", "y"],
                    "type": "radioGroup",
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.rectangular_spiral",
            "label": "Rectangular Spiral",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-2.275000 -33.025000 50.050000 36.550000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.182750;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.182750;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.182750;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.182750;}.reference{fill:none;stroke:#221f20;stroke-width:0.127925;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:1.462000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.182750;}.dashed{stroke-dasharray:0.913750,0.548250;}.port{fill:none;stroke:#805080;stroke-width:0.365500;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.274125;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.731000 L 1.096500,0 0,0.731000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.548250 C 0.731000,-0.548250 0.731000,0.548250 0,0.548250" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.383775" /><g id="bend_SNYOJKDNCMS2UNH6TW2CUMPZV7IM54OG6AZTVRPHLMNUDWNXWQQA-0x56b8e5dd31e0"><path class="layer_1_0" d="M 0.000000,-1.250000 0.504000,-1.269000 0.756000,-1.292000 1.006000,-1.325000 1.502000,-1.419000 1.990000,-1.550000 2.466000,-1.717000 2.929000,-1.918000 3.375000,-2.154000 3.802000,-2.423000 4.209000,-2.723000 4.591000,-3.052000 4.948000,-3.409000 5.277000,-3.791000 5.577000,-4.198000 5.846000,-4.625000 6.082000,-5.071000 6.283000,-5.534000 6.450000,-6.010000 6.581000,-6.498000 6.675000,-6.994000 6.708000,-7.244000 6.745000,-7.748000 6.750000,-8.000000 9.250000,-8.000000 9.244000,-7.654000 9.224000,-7.309000 9.192000,-6.964000 9.147000,-6.621000 9.089000,-6.280000 9.018000,-5.942000 8.935000,-5.606000 8.839000,-5.274000 8.731000,-4.945000 8.611000,-4.621000 8.478000,-4.301000 8.334000,-3.987000 8.178000,-3.678000 8.011000,-3.375000 7.832000,-3.079000 7.643000,-2.789000 7.443000,-2.507000 7.232000,-2.233000 7.011000,-1.966000 6.781000,-1.708000 6.541000,-1.459000 6.292000,-1.219000 6.034000,-0.989000 5.767000,-0.768000 5.493000,-0.557000 5.211000,-0.357000 4.921000,-0.168000 4.625000,0.011000 4.322000,0.178000 4.013000,0.334000 3.699000,0.478000 3.379000,0.611000 3.055000,0.731000 2.726000,0.839000 2.394000,0.935000 2.058000,1.018000 1.720000,1.089000 1.379000,1.147000 1.036000,1.192000 0.691000,1.224000 0.346000,1.244000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 0.290000,-0.255000 0.868000,-0.299000 1.155000,-0.337000 1.441000,-0.385000 1.725000,-0.444000 2.006000,-0.514000 2.284000,-0.594000 2.560000,-0.685000 2.831000,-0.786000 3.363000,-1.017000 3.875000,-1.288000 4.123000,-1.438000 4.366000,-1.597000 4.602000,-1.764000 4.832000,-1.941000 5.055000,-2.126000 5.271000,-2.319000 5.480000,-2.520000 5.681000,-2.729000 5.874000,-2.945000 6.059000,-3.168000 6.236000,-3.398000 6.403000,-3.634000 6.562000,-3.877000 6.712000,-4.125000 6.983000,-4.637000 7.214000,-5.169000 7.315000,-5.440000 7.406000,-5.716000 7.486000,-5.994000 7.556000,-6.275000 7.615000,-6.559000 7.663000,-6.845000 7.701000,-7.132000 7.728000,-7.421000 7.745000,-7.710000 7.750000,-8.000000 8.250000,-8.000000 8.244000,-7.692000 8.227000,-7.383000 8.198000,-7.076000 8.158000,-6.770000 8.106000,-6.466000 8.043000,-6.164000 7.969000,-5.865000 7.883000,-5.568000 7.787000,-5.275000 7.680000,-4.986000 7.562000,-4.701000 7.433000,-4.420000 7.294000,-4.145000 7.145000,-3.875000 6.985000,-3.611000 6.816000,-3.353000 6.638000,-3.101000 6.450000,-2.856000 6.253000,-2.619000 6.048000,-2.389000 5.834000,-2.166000 5.611000,-1.952000 5.381000,-1.747000 5.144000,-1.550000 4.899000,-1.362000 4.647000,-1.184000 4.389000,-1.015000 4.125000,-0.855000 3.855000,-0.706000 3.580000,-0.567000 3.299000,-0.438000 3.014000,-0.320000 2.725000,-0.213000 2.432000,-0.117000 2.135000,-0.031000 1.836000,0.043000 1.534000,0.106000 1.230000,0.158000 0.924000,0.198000 0.617000,0.227000 0.308000,0.244000 0.000000,0.250000 z" /></g><g id="bend_ZLWQN2BLU7GVOJC2NGIYJM2FZBQY7UUFBWUPSBLQPC2636QHNYBA-0x56b8e5ddc2b0"><path class="layer_1_0" d="M 0.000000,-1.250000 0.346000,-1.244000 0.691000,-1.224000 1.036000,-1.192000 1.379000,-1.147000 1.720000,-1.089000 2.058000,-1.018000 2.394000,-0.935000 2.726000,-0.839000 3.055000,-0.731000 3.379000,-0.611000 3.699000,-0.478000 4.013000,-0.334000 4.322000,-0.178000 4.625000,-0.011000 4.921000,0.168000 5.211000,0.357000 5.493000,0.557000 5.767000,0.768000 6.034000,0.989000 6.292000,1.219000 6.541000,1.459000 6.781000,1.708000 7.011000,1.966000 7.232000,2.233000 7.443000,2.507000 7.643000,2.789000 7.832000,3.079000 8.011000,3.375000 8.178000,3.678000 8.334000,3.987000 8.478000,4.301000 8.611000,4.621000 8.731000,4.945000 8.839000,5.274000 8.935000,5.606000 9.018000,5.942000 9.089000,6.280000 9.147000,6.621000 9.192000,6.964000 9.224000,7.309000 9.244000,7.654000 9.250000,8.000000 6.750000,8.000000 6.745000,7.748000 6.708000,7.244000 6.675000,6.994000 6.581000,6.498000 6.450000,6.010000 6.283000,5.534000 6.082000,5.071000 5.846000,4.625000 5.577000,4.198000 5.277000,3.791000 4.948000,3.409000 4.591000,3.052000 4.209000,2.723000 3.802000,2.423000 3.375000,2.154000 2.929000,1.918000 2.466000,1.717000 1.990000,1.550000 1.502000,1.419000 1.006000,1.325000 0.756000,1.292000 0.504000,1.269000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 0.308000,-0.244000 0.617000,-0.227000 0.924000,-0.198000 1.230000,-0.158000 1.534000,-0.106000 1.836000,-0.043000 2.135000,0.031000 2.432000,0.117000 2.725000,0.213000 3.014000,0.320000 3.299000,0.438000 3.580000,0.567000 3.855000,0.706000 4.125000,0.855000 4.389000,1.015000 4.647000,1.184000 4.899000,1.362000 5.144000,1.550000 5.381000,1.747000 5.611000,1.952000 5.834000,2.166000 6.048000,2.389000 6.253000,2.619000 6.450000,2.856000 6.638000,3.101000 6.816000,3.353000 6.985000,3.611000 7.145000,3.875000 7.294000,4.145000 7.433000,4.420000 7.562000,4.701000 7.680000,4.986000 7.787000,5.275000 7.883000,5.568000 7.969000,5.865000 8.043000,6.164000 8.106000,6.466000 8.158000,6.770000 8.198000,7.076000 8.227000,7.383000 8.244000,7.692000 8.250000,8.000000 7.750000,8.000000 7.745000,7.710000 7.728000,7.421000 7.701000,7.132000 7.663000,6.845000 7.615000,6.559000 7.556000,6.275000 7.486000,5.994000 7.406000,5.716000 7.315000,5.440000 7.214000,5.169000 6.983000,4.637000 6.712000,4.125000 6.562000,3.877000 6.403000,3.634000 6.236000,3.398000 6.059000,3.168000 5.874000,2.945000 5.681000,2.729000 5.480000,2.520000 5.271000,2.319000 5.055000,2.126000 4.832000,1.941000 4.602000,1.764000 4.366000,1.597000 4.123000,1.438000 3.875000,1.288000 3.363000,1.017000 2.831000,0.786000 2.560000,0.685000 2.284000,0.594000 2.006000,0.514000 1.725000,0.444000 1.441000,0.385000 1.155000,0.337000 0.868000,0.299000 0.290000,0.255000 0.000000,0.250000 z" /></g><g id="straight_X6HL6ZO4ULPCSYDWM7CC7FLOS64VCBBYSEFCEJZY5X6MQILRPHSQ-0x56b8e5ddf900"><path class="layer_1_0" d="M 0.000000,-1.250000 2.250000,-1.250000 2.250000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 2.250000,-0.250000 2.250000,0.250000 0.000000,0.250000 z" /></g><g id="straight_H6VWTV3E5ZZTEI5W56O6OVD5XBJGBGIHHTDMXZ2NIPMCUPJYE42Q-0x56b8e5deb7f0"><path class="layer_1_0" d="M 0.000000,-1.250000 35.250000,-1.250000 35.250000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 35.250000,-0.250000 35.250000,0.250000 0.000000,0.250000 z" /></g><g id="straight_IWGUTVE3GEHX3FZCGTLNZU7LHWFTU3AUTJIL3IV6G73G5VYTAKNA-0x56b8e5de1df0"><path class="layer_1_0" d="M 0.000000,-1.250000 18.250000,-1.250000 18.250000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 18.250000,-0.250000 18.250000,0.250000 0.000000,0.250000 z" /></g><g id="straight_Y5YNAHU3OVDXKFIP7HVRNASNSKLPMW4X6AGVODRQEADSRXVY322A-0x56b8e5debfa0"><path class="layer_1_0" d="M 0.000000,-1.250000 11.250000,-1.250000 11.250000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 11.250000,-0.250000 11.250000,0.250000 0.000000,0.250000 z" /></g><g id="straight_DFALBPXFPLF6OCCCEGEL6VBN7HW74KFERPMLQQB5CEPAZ4TEQFAA-0x56b8e5de1810"><path class="layer_1_0" d="M 0.000000,-1.250000 6.750000,-1.250000 6.750000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 6.750000,-0.250000 6.750000,0.250000 0.000000,0.250000 z" /></g><g id="straight_2PLHIIMQTQQ6X3T5LEMEHAR4TM4WWMDROE7MSHUJFFHLNXQMIUAA-0x56b8e5de5890"><path class="layer_1_0" d="M 0.000000,-1.250000 22.750000,-1.250000 22.750000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 22.750000,-0.250000 22.750000,0.250000 0.000000,0.250000 z" /></g></defs><g transform="scale(1 -1)"><g id="rectangular_spiral-0x56b8e5ddc790"><use transform="translate(22.750000 14.750000) rotate(270.000000)" href="#bend_SNYOJKDNCMS2UNH6TW2CUMPZV7IM54OG6AZTVRPHLMNUDWNXWQQA-0x56b8e5dd31e0" /><use transform="translate(30.750000 22.750000) rotate(180.000000)" href="#bend_ZLWQN2BLU7GVOJC2NGIYJM2FZBQY7UUFBWUPSBLQPC2636QHNYBA-0x56b8e5ddc2b0" /><use transform="translate(14.750000 6.750000) rotate(180.000000)" href="#bend_SNYOJKDNCMS2UNH6TW2CUMPZV7IM54OG6AZTVRPHLMNUDWNXWQQA-0x56b8e5dd31e0" /><use transform="translate(38.750000 14.750000) rotate(90.000000)" href="#bend_ZLWQN2BLU7GVOJC2NGIYJM2FZBQY7UUFBWUPSBLQPC2636QHNYBA-0x56b8e5ddc2b0" /><use transform="translate(6.750000 14.750000) rotate(90.000000)" href="#straight_X6HL6ZO4ULPCSYDWM7CC7FLOS64VCBBYSEFCEJZY5X6MQILRPHSQ-0x56b8e5ddf900" /><use transform="translate(38.750000 12.500000) rotate(90.000000)" href="#straight_X6HL6ZO4ULPCSYDWM7CC7FLOS64VCBBYSEFCEJZY5X6MQILRPHSQ-0x56b8e5ddf900" /><use transform="translate(6.750000 17.000000) rotate(90.000000)" href="#bend_SNYOJKDNCMS2UNH6TW2CUMPZV7IM54OG6AZTVRPHLMNUDWNXWQQA-0x56b8e5dd31e0" /><use transform="translate(30.750000 4.500000)" href="#bend_ZLWQN2BLU7GVOJC2NGIYJM2FZBQY7UUFBWUPSBLQPC2636QHNYBA-0x56b8e5ddc2b0" /><use transform="translate(14.750000 25.000000)" href="#straight_IWGUTVE3GEHX3FZCGTLNZU7LHWFTU3AUTJIL3IV6G73G5VYTAKNA-0x56b8e5de1df0" /><use transform="translate(12.500000 4.500000)" href="#straight_IWGUTVE3GEHX3FZCGTLNZU7LHWFTU3AUTJIL3IV6G73G5VYTAKNA-0x56b8e5de1df0" /><use transform="translate(33.000000 25.000000)" href="#bend_SNYOJKDNCMS2UNH6TW2CUMPZV7IM54OG6AZTVRPHLMNUDWNXWQQA-0x56b8e5dd31e0" /><use transform="translate(4.500000 12.500000) rotate(270.000000)" href="#bend_ZLWQN2BLU7GVOJC2NGIYJM2FZBQY7UUFBWUPSBLQPC2636QHNYBA-0x56b8e5ddc2b0" /><use transform="translate(41.000000 17.000000) rotate(270.000000)" href="#straight_DFALBPXFPLF6OCCCEGEL6VBN7HW74KFERPMLQQB5CEPAZ4TEQFAA-0x56b8e5de1810" /><use transform="translate(4.500000 19.250000) rotate(270.000000)" href="#straight_DFALBPXFPLF6OCCCEGEL6VBN7HW74KFERPMLQQB5CEPAZ4TEQFAA-0x56b8e5de1810" /><use transform="translate(41.000000 10.250000) rotate(270.000000)" href="#bend_SNYOJKDNCMS2UNH6TW2CUMPZV7IM54OG6AZTVRPHLMNUDWNXWQQA-0x56b8e5dd31e0" /><use transform="translate(12.500000 27.250000) rotate(180.000000)" href="#bend_ZLWQN2BLU7GVOJC2NGIYJM2FZBQY7UUFBWUPSBLQPC2636QHNYBA-0x56b8e5ddc2b0" /><use transform="translate(33.000000 2.250000) rotate(180.000000)" href="#straight_2PLHIIMQTQQ6X3T5LEMEHAR4TM4WWMDROE7MSHUJFFHLNXQMIUAA-0x56b8e5de5890" /><use transform="translate(35.250000 27.250000) rotate(180.000000)" href="#straight_2PLHIIMQTQQ6X3T5LEMEHAR4TM4WWMDROE7MSHUJFFHLNXQMIUAA-0x56b8e5de5890" /><use transform="translate(10.250000 2.250000) rotate(180.000000)" href="#bend_SNYOJKDNCMS2UNH6TW2CUMPZV7IM54OG6AZTVRPHLMNUDWNXWQQA-0x56b8e5dd31e0" /><use transform="translate(43.250000 19.250000) rotate(90.000000)" href="#bend_ZLWQN2BLU7GVOJC2NGIYJM2FZBQY7UUFBWUPSBLQPC2636QHNYBA-0x56b8e5ddc2b0" /><use transform="translate(2.250000 10.250000) rotate(90.000000)" href="#straight_Y5YNAHU3OVDXKFIP7HVRNASNSKLPMW4X6AGVODRQEADSRXVY322A-0x56b8e5debfa0" /><use transform="translate(43.250000 8.000000) rotate(90.000000)" href="#straight_Y5YNAHU3OVDXKFIP7HVRNASNSKLPMW4X6AGVODRQEADSRXVY322A-0x56b8e5debfa0" /><use transform="translate(2.250000 21.500000) rotate(90.000000)" href="#bend_SNYOJKDNCMS2UNH6TW2CUMPZV7IM54OG6AZTVRPHLMNUDWNXWQQA-0x56b8e5dd31e0" /><use transform="translate(35.250000 0.000000)" href="#bend_ZLWQN2BLU7GVOJC2NGIYJM2FZBQY7UUFBWUPSBLQPC2636QHNYBA-0x56b8e5ddc2b0" /><use transform="translate(0.000000 0.000000)" href="#straight_H6VWTV3E5ZZTEI5W56O6OVD5XBJGBGIHHTDMXZ2NIPMCUPJYE42Q-0x56b8e5deb7f0" /><use transform="translate(10.250000 29.500000)" href="#straight_H6VWTV3E5ZZTEI5W56O6OVD5XBJGBGIHHTDMXZ2NIPMCUPJYE42Q-0x56b8e5deb7f0" /><g transform="translate(45.500000 29.500000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section. A tuple with 2 values can be used, one for each coupler side.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Coupling Distance",
                    "name": "coupling_distance",
                    "tooltip": "Distance between bus and ring waveguide centers.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Radius",
                    "name": "radius",
                    "tooltip": "Central ring radius.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Bus Length",
                    "name": "bus_length",
                    "tooltip": "Length of the bus waveguide added to each side of the straight coupling section. If both ``bus_length`` and ``coupling_length`` are 0, the bus waveguide is not included.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bends that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "type": "number",
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                },
                {
                    "label": "Coupling Length",
                    "name": "coupling_length",
                    "tooltip": "Length of straigh coupling region.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.ring_coupler",
            "label": "Ring Coupler",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-10.175000 -0.925000 20.350000 11.750000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.058750;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.058750;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.058750;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.058750;}.reference{fill:none;stroke:#221f20;stroke-width:0.041125;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.470000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.058750;}.dashed{stroke-dasharray:0.293750,0.176250;}.port{fill:none;stroke:#805080;stroke-width:0.117500;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.088125;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.235000 L 0.352500,0 0,0.235000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.176250 C 0.235000,-0.176250 0.235000,0.176250 0,0.176250" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.123375" /></defs><g transform="scale(1 -1)"><g id="ring_coupler-0x56b8e5df76b0"><path class="layer_1_0" d="M -8.000000,-9.900000 8.000000,-9.900000 8.000000,-7.400000 -8.000000,-7.400000 z" /><path class="layer_1_0" d="M 6.750000,0.000000 6.731000,-0.504000 6.708000,-0.756000 6.675000,-1.006000 6.581000,-1.502000 6.450000,-1.990000 6.283000,-2.466000 6.082000,-2.929000 5.846000,-3.375000 5.577000,-3.802000 5.277000,-4.209000 4.948000,-4.591000 4.591000,-4.948000 4.209000,-5.277000 3.802000,-5.577000 3.375000,-5.846000 2.929000,-6.082000 2.466000,-6.283000 1.990000,-6.450000 1.502000,-6.581000 1.006000,-6.675000 0.756000,-6.708000 0.252000,-6.745000 0.000000,-6.750000 -0.504000,-6.731000 -0.756000,-6.708000 -1.006000,-6.675000 -1.502000,-6.581000 -1.990000,-6.450000 -2.466000,-6.283000 -2.929000,-6.082000 -3.375000,-5.846000 -3.802000,-5.577000 -4.209000,-5.277000 -4.591000,-4.948000 -4.948000,-4.591000 -5.277000,-4.209000 -5.577000,-3.802000 -5.846000,-3.375000 -6.082000,-2.929000 -6.283000,-2.466000 -6.450000,-1.990000 -6.581000,-1.502000 -6.675000,-1.006000 -6.708000,-0.756000 -6.745000,-0.252000 -6.750000,0.000000 -9.250000,0.000000 -9.244000,-0.346000 -9.224000,-0.691000 -9.192000,-1.036000 -9.147000,-1.379000 -9.089000,-1.720000 -9.018000,-2.058000 -8.935000,-2.394000 -8.839000,-2.726000 -8.731000,-3.055000 -8.611000,-3.379000 -8.478000,-3.699000 -8.334000,-4.013000 -8.178000,-4.322000 -8.011000,-4.625000 -7.832000,-4.921000 -7.643000,-5.211000 -7.443000,-5.493000 -7.232000,-5.767000 -7.011000,-6.034000 -6.781000,-6.292000 -6.541000,-6.541000 -6.292000,-6.781000 -6.034000,-7.011000 -5.767000,-7.232000 -5.493000,-7.443000 -5.211000,-7.643000 -4.921000,-7.832000 -4.625000,-8.011000 -4.322000,-8.178000 -4.013000,-8.334000 -3.699000,-8.478000 -3.379000,-8.611000 -3.055000,-8.731000 -2.726000,-8.839000 -2.394000,-8.935000 -2.058000,-9.018000 -1.720000,-9.089000 -1.379000,-9.147000 -1.036000,-9.192000 -0.691000,-9.224000 -0.346000,-9.244000 0.000000,-9.250000 0.346000,-9.244000 0.691000,-9.224000 1.036000,-9.192000 1.379000,-9.147000 1.720000,-9.089000 2.058000,-9.018000 2.394000,-8.935000 2.726000,-8.839000 3.055000,-8.731000 3.379000,-8.611000 3.699000,-8.478000 4.013000,-8.334000 4.322000,-8.178000 4.625000,-8.011000 4.921000,-7.832000 5.211000,-7.643000 5.493000,-7.443000 5.767000,-7.232000 6.034000,-7.011000 6.292000,-6.781000 6.541000,-6.541000 6.781000,-6.292000 7.011000,-6.034000 7.232000,-5.767000 7.443000,-5.493000 7.643000,-5.211000 7.832000,-4.921000 8.011000,-4.625000 8.178000,-4.322000 8.334000,-4.013000 8.478000,-3.699000 8.611000,-3.379000 8.731000,-3.055000 8.839000,-2.726000 8.935000,-2.394000 9.018000,-2.058000 9.089000,-1.720000 9.147000,-1.379000 9.192000,-1.036000 9.224000,-0.691000 9.244000,-0.346000 9.250000,0.000000 z" /><path class="layer_2_0" d="M -8.000000,-8.900000 8.000000,-8.900000 8.000000,-8.400000 -8.000000,-8.400000 z" /><path class="layer_2_0" d="M 7.750000,0.000000 7.745000,-0.290000 7.701000,-0.868000 7.663000,-1.155000 7.615000,-1.441000 7.556000,-1.725000 7.486000,-2.006000 7.406000,-2.284000 7.315000,-2.560000 7.214000,-2.831000 6.983000,-3.363000 6.712000,-3.875000 6.562000,-4.123000 6.403000,-4.366000 6.236000,-4.602000 6.059000,-4.832000 5.874000,-5.055000 5.681000,-5.271000 5.480000,-5.480000 5.271000,-5.681000 5.055000,-5.874000 4.832000,-6.059000 4.602000,-6.236000 4.366000,-6.403000 4.123000,-6.562000 3.875000,-6.712000 3.363000,-6.983000 2.831000,-7.214000 2.560000,-7.315000 2.284000,-7.406000 2.006000,-7.486000 1.725000,-7.556000 1.441000,-7.615000 1.155000,-7.663000 0.868000,-7.701000 0.579000,-7.728000 0.290000,-7.745000 0.000000,-7.750000 -0.290000,-7.745000 -0.868000,-7.701000 -1.155000,-7.663000 -1.441000,-7.615000 -1.725000,-7.556000 -2.006000,-7.486000 -2.284000,-7.406000 -2.560000,-7.315000 -2.831000,-7.214000 -3.363000,-6.983000 -3.875000,-6.712000 -4.123000,-6.562000 -4.366000,-6.403000 -4.602000,-6.236000 -4.832000,-6.059000 -5.055000,-5.874000 -5.271000,-5.681000 -5.480000,-5.480000 -5.681000,-5.271000 -5.874000,-5.055000 -6.059000,-4.832000 -6.236000,-4.602000 -6.403000,-4.366000 -6.562000,-4.123000 -6.712000,-3.875000 -6.983000,-3.363000 -7.214000,-2.831000 -7.315000,-2.560000 -7.406000,-2.284000 -7.486000,-2.006000 -7.556000,-1.725000 -7.615000,-1.441000 -7.663000,-1.155000 -7.701000,-0.868000 -7.728000,-0.579000 -7.745000,-0.290000 -7.750000,0.000000 -8.250000,0.000000 -8.244000,-0.308000 -8.227000,-0.617000 -8.198000,-0.924000 -8.158000,-1.230000 -8.106000,-1.534000 -8.043000,-1.836000 -7.969000,-2.135000 -7.883000,-2.432000 -7.787000,-2.725000 -7.680000,-3.014000 -7.562000,-3.299000 -7.433000,-3.580000 -7.294000,-3.855000 -7.145000,-4.125000 -6.985000,-4.389000 -6.816000,-4.647000 -6.638000,-4.899000 -6.450000,-5.144000 -6.253000,-5.381000 -6.048000,-5.611000 -5.834000,-5.834000 -5.611000,-6.048000 -5.381000,-6.253000 -5.144000,-6.450000 -4.899000,-6.638000 -4.647000,-6.816000 -4.389000,-6.985000 -4.125000,-7.145000 -3.855000,-7.294000 -3.580000,-7.433000 -3.299000,-7.562000 -3.014000,-7.680000 -2.725000,-7.787000 -2.432000,-7.883000 -2.135000,-7.969000 -1.836000,-8.043000 -1.534000,-8.106000 -1.230000,-8.158000 -0.924000,-8.198000 -0.617000,-8.227000 -0.308000,-8.244000 0.000000,-8.250000 0.308000,-8.244000 0.617000,-8.227000 0.924000,-8.198000 1.230000,-8.158000 1.534000,-8.106000 1.836000,-8.043000 2.135000,-7.969000 2.432000,-7.883000 2.725000,-7.787000 3.014000,-7.680000 3.299000,-7.562000 3.580000,-7.433000 3.855000,-7.294000 4.125000,-7.145000 4.389000,-6.985000 4.647000,-6.816000 4.899000,-6.638000 5.144000,-6.450000 5.381000,-6.253000 5.611000,-6.048000 5.834000,-5.834000 6.048000,-5.611000 6.253000,-5.381000 6.450000,-5.144000 6.638000,-4.899000 6.816000,-4.647000 6.985000,-4.389000 7.145000,-4.125000 7.294000,-3.855000 7.433000,-3.580000 7.562000,-3.299000 7.680000,-3.014000 7.787000,-2.725000 7.883000,-2.432000 7.969000,-2.135000 8.043000,-1.836000 8.106000,-1.534000 8.158000,-1.230000 8.198000,-0.924000 8.227000,-0.617000 8.244000,-0.308000 8.250000,0.000000 z" /><g transform="translate(8.000000 0.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(8.000000 -8.650000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-8.000000 0.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-8.000000 -8.650000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Length",
                    "name": "length",
                    "tooltip": "Length of the S bend in the main propagation direction.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Offset",
                    "name": "offset",
                    "tooltip": "Side offset of the S bend.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bends that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "type": "number",
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.s_bend",
            "label": "S Bend",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-0.400000 -3.650000 8.800000 5.300000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.026500;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.026500;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.026500;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.026500;}.reference{fill:none;stroke:#221f20;stroke-width:0.018550;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.212000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.026500;}.dashed{stroke-dasharray:0.132500,0.079500;}.port{fill:none;stroke:#805080;stroke-width:0.053000;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.039750;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.106000 L 0.159000,0 0,0.106000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.079500 C 0.106000,-0.079500 0.106000,0.079500 0,0.079500" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.055650" /></defs><g transform="scale(1 -1)"><g id="s_bend-0x56b8e5e003e0"><path class="layer_1_0" d="M 0.000000,-1.250000 0.398000,-1.242000 0.795000,-1.218000 1.191000,-1.177000 1.585000,-1.120000 1.977000,-1.048000 2.365000,-0.959000 2.749000,-0.854000 3.128000,-0.734000 3.503000,-0.599000 3.871000,-0.449000 4.233000,-0.283000 4.588000,-0.103000 4.852000,0.031000 5.121000,0.154000 5.395000,0.266000 5.674000,0.367000 5.956000,0.456000 6.242000,0.534000 6.530000,0.599000 6.821000,0.654000 7.114000,0.696000 7.409000,0.726000 7.704000,0.744000 8.000000,0.750000 8.000000,3.250000 7.602000,3.242000 7.205000,3.218000 6.809000,3.177000 6.415000,3.120000 6.023000,3.048000 5.635000,2.959000 5.251000,2.854000 4.872000,2.734000 4.497000,2.599000 4.129000,2.449000 3.767000,2.283000 3.412000,2.103000 3.148000,1.969000 2.879000,1.846000 2.605000,1.734000 2.326000,1.633000 2.044000,1.544000 1.758000,1.466000 1.470000,1.401000 1.179000,1.346000 0.886000,1.304000 0.591000,1.274000 0.296000,1.256000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 0.357000,-0.243000 0.714000,-0.221000 1.069000,-0.184000 1.423000,-0.134000 1.774000,-0.068000 2.122000,0.011000 2.467000,0.105000 2.808000,0.213000 3.143000,0.334000 3.474000,0.469000 3.799000,0.618000 4.118000,0.779000 4.418000,0.932000 4.724000,1.072000 5.036000,1.199000 5.353000,1.314000 5.674000,1.415000 5.999000,1.504000 6.327000,1.579000 6.659000,1.640000 6.992000,1.688000 7.327000,1.723000 7.663000,1.743000 8.000000,1.750000 8.000000,2.250000 7.643000,2.243000 7.286000,2.221000 6.931000,2.184000 6.577000,2.134000 6.226000,2.068000 5.878000,1.989000 5.533000,1.895000 5.192000,1.787000 4.857000,1.666000 4.526000,1.531000 4.201000,1.382000 3.882000,1.221000 3.582000,1.068000 3.276000,0.928000 2.964000,0.801000 2.647000,0.686000 2.326000,0.585000 2.001000,0.496000 1.673000,0.421000 1.341000,0.360000 1.008000,0.312000 0.673000,0.277000 0.337000,0.257000 0.000000,0.250000 z" /><g transform="translate(8.000000 2.000000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section. A tuple with 2 values can be used, one for each coupler side.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Coupling Distance",
                    "name": "coupling_distance",
                    "tooltip": "Distance between waveguide centers.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "S Bend Length",
                    "name": "s_bend_length",
                    "tooltip": "Length of the S bends.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "S Bend Offset",
                    "name": "s_bend_offset",
                    "tooltip": "Offset of the S bends.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bends that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "type": "number",
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                },
                {
                    "label": "Coupling Length",
                    "name": "coupling_length",
                    "tooltip": "Length of straigh coupling region.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.s_bend_coupler",
            "label": "S Bend Coupler",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-0.774600 -6.674600 17.041200 8.699200"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.043496;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.043496;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.043496;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.043496;}.reference{fill:none;stroke:#221f20;stroke-width:0.030447;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.347968px;}.terminal{fill:none;stroke:#805080;stroke-width:0.043496;}.dashed{stroke-dasharray:0.217480,0.130488;}.port{fill:none;stroke:#805080;stroke-width:0.086992;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.065244;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.173984 L 0.260976,0 0,0.173984" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.130488 C 0.173984,-0.130488 0.173984,0.130488 0,0.130488" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.091342" /></defs><g transform="scale(1 -1)"><g id="s_bend_coupler-0x56b8e5e07520"><path class="layer_1_0" d="M 0.000000,-1.250000 0.389000,-1.242000 0.778000,-1.217000 1.166000,-1.176000 1.551000,-1.119000 1.933000,-1.046000 2.313000,-0.956000 2.688000,-0.851000 3.058000,-0.730000 3.423000,-0.594000 3.781000,-0.442000 4.133000,-0.275000 4.478000,-0.094000 4.730000,0.039000 4.987000,0.160000 5.248000,0.271000 5.515000,0.371000 5.785000,0.459000 6.058000,0.536000 6.335000,0.601000 6.614000,0.654000 6.895000,0.696000 7.178000,0.726000 7.462000,0.744000 7.746000,0.750000 8.030000,0.744000 8.314000,0.726000 8.597000,0.696000 8.878000,0.654000 9.157000,0.601000 9.434000,0.536000 9.707000,0.459000 9.977000,0.371000 10.244000,0.271000 10.505000,0.160000 10.762000,0.039000 11.014000,-0.094000 11.359000,-0.275000 11.711000,-0.442000 12.069000,-0.594000 12.434000,-0.730000 12.804000,-0.851000 13.179000,-0.956000 13.559000,-1.046000 13.941000,-1.119000 14.326000,-1.176000 14.714000,-1.217000 15.103000,-1.242000 15.492000,-1.250000 15.492000,1.250000 15.208000,1.256000 14.924000,1.274000 14.641000,1.304000 14.360000,1.346000 14.081000,1.399000 13.804000,1.464000 13.531000,1.541000 13.261000,1.629000 12.994000,1.729000 12.733000,1.840000 12.476000,1.961000 12.224000,2.094000 11.879000,2.275000 11.527000,2.442000 11.169000,2.594000 10.804000,2.730000 10.434000,2.851000 10.059000,2.956000 9.679000,3.046000 9.297000,3.119000 8.912000,3.176000 8.524000,3.217000 8.135000,3.242000 7.746000,3.250000 7.357000,3.242000 6.968000,3.217000 6.580000,3.176000 6.195000,3.119000 5.813000,3.046000 5.433000,2.956000 5.058000,2.851000 4.688000,2.730000 4.323000,2.594000 3.965000,2.442000 3.613000,2.275000 3.268000,2.094000 3.016000,1.961000 2.759000,1.840000 2.498000,1.729000 2.231000,1.629000 1.961000,1.541000 1.688000,1.464000 1.411000,1.399000 1.132000,1.346000 0.851000,1.304000 0.568000,1.274000 0.284000,1.256000 0.000000,1.250000 z" /><path class="layer_1_0" d="M 15.492000,5.900000 15.103000,5.892000 14.714000,5.867000 14.326000,5.826000 13.941000,5.769000 13.559000,5.696000 13.179000,5.606000 12.804000,5.501000 12.434000,5.380000 12.069000,5.244000 11.711000,5.092000 11.359000,4.925000 11.014000,4.744000 10.762000,4.611000 10.505000,4.490000 10.244000,4.379000 9.977000,4.279000 9.707000,4.191000 9.434000,4.114000 9.157000,4.049000 8.878000,3.996000 8.597000,3.954000 8.314000,3.924000 8.030000,3.906000 7.746000,3.900000 7.462000,3.906000 7.178000,3.924000 6.895000,3.954000 6.614000,3.996000 6.335000,4.049000 6.058000,4.114000 5.785000,4.191000 5.515000,4.279000 5.248000,4.379000 4.987000,4.490000 4.730000,4.611000 4.478000,4.744000 4.133000,4.925000 3.781000,5.092000 3.423000,5.244000 3.058000,5.380000 2.688000,5.501000 2.313000,5.606000 1.933000,5.696000 1.551000,5.769000 1.166000,5.826000 0.778000,5.867000 0.389000,5.892000 0.000000,5.900000 0.000000,3.400000 0.284000,3.394000 0.568000,3.376000 0.851000,3.346000 1.132000,3.304000 1.411000,3.251000 1.688000,3.186000 1.961000,3.109000 2.231000,3.021000 2.498000,2.921000 2.759000,2.810000 3.016000,2.689000 3.268000,2.556000 3.613000,2.375000 3.965000,2.208000 4.323000,2.056000 4.688000,1.920000 5.058000,1.799000 5.433000,1.694000 5.813000,1.604000 6.195000,1.531000 6.580000,1.474000 6.968000,1.433000 7.357000,1.408000 7.746000,1.400000 8.135000,1.408000 8.524000,1.433000 8.912000,1.474000 9.297000,1.531000 9.679000,1.604000 10.059000,1.694000 10.434000,1.799000 10.804000,1.920000 11.169000,2.056000 11.527000,2.208000 11.879000,2.375000 12.224000,2.556000 12.476000,2.689000 12.733000,2.810000 12.994000,2.921000 13.261000,3.021000 13.531000,3.109000 13.804000,3.186000 14.081000,3.251000 14.360000,3.304000 14.641000,3.346000 14.924000,3.376000 15.208000,3.394000 15.492000,3.400000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 0.347000,-0.243000 0.694000,-0.221000 1.040000,-0.184000 1.383000,-0.133000 1.724000,-0.068000 2.063000,0.012000 2.397000,0.106000 2.727000,0.214000 3.053000,0.336000 3.373000,0.471000 3.687000,0.620000 3.994000,0.781000 4.283000,0.933000 4.578000,1.073000 4.878000,1.200000 5.184000,1.314000 5.494000,1.416000 5.808000,1.504000 6.126000,1.579000 6.447000,1.640000 6.769000,1.688000 7.094000,1.723000 7.420000,1.743000 7.746000,1.750000 8.072000,1.743000 8.398000,1.723000 8.723000,1.688000 9.045000,1.640000 9.366000,1.579000 9.684000,1.504000 9.998000,1.416000 10.308000,1.314000 10.614000,1.200000 10.914000,1.073000 11.209000,0.933000 11.498000,0.781000 11.805000,0.620000 12.119000,0.471000 12.439000,0.336000 12.765000,0.214000 13.095000,0.106000 13.429000,0.012000 13.768000,-0.068000 14.109000,-0.133000 14.452000,-0.184000 14.798000,-0.221000 15.145000,-0.243000 15.492000,-0.250000 15.492000,0.250000 15.166000,0.257000 14.840000,0.277000 14.515000,0.312000 14.193000,0.360000 13.872000,0.421000 13.554000,0.496000 13.240000,0.584000 12.930000,0.686000 12.624000,0.800000 12.324000,0.927000 12.029000,1.067000 11.740000,1.219000 11.433000,1.381000 11.119000,1.529000 10.799000,1.664000 10.473000,1.786000 10.143000,1.894000 9.809000,1.988000 9.470000,2.068000 9.129000,2.133000 8.786000,2.184000 8.440000,2.221000 8.093000,2.243000 7.746000,2.250000 7.399000,2.243000 7.052000,2.221000 6.706000,2.184000 6.363000,2.133000 6.022000,2.068000 5.683000,1.988000 5.349000,1.894000 5.019000,1.786000 4.693000,1.664000 4.373000,1.529000 4.059000,1.381000 3.752000,1.219000 3.463000,1.067000 3.168000,0.927000 2.868000,0.800000 2.562000,0.686000 2.252000,0.584000 1.938000,0.496000 1.620000,0.421000 1.299000,0.360000 0.977000,0.312000 0.652000,0.277000 0.326000,0.257000 0.000000,0.250000 z" /><path class="layer_2_0" d="M 15.492000,4.900000 15.145000,4.893000 14.798000,4.871000 14.452000,4.834000 14.109000,4.783000 13.768000,4.718000 13.429000,4.638000 13.095000,4.544000 12.765000,4.436000 12.439000,4.314000 12.119000,4.179000 11.805000,4.031000 11.498000,3.869000 11.209000,3.717000 10.914000,3.577000 10.614000,3.450000 10.308000,3.336000 9.998000,3.234000 9.684000,3.146000 9.366000,3.071000 9.045000,3.010000 8.723000,2.962000 8.398000,2.927000 8.072000,2.907000 7.746000,2.900000 7.420000,2.907000 7.094000,2.927000 6.769000,2.962000 6.447000,3.010000 6.126000,3.071000 5.808000,3.146000 5.494000,3.234000 5.184000,3.336000 4.878000,3.450000 4.578000,3.577000 4.283000,3.717000 3.994000,3.869000 3.687000,4.031000 3.373000,4.179000 3.053000,4.314000 2.727000,4.436000 2.397000,4.544000 2.063000,4.638000 1.724000,4.718000 1.383000,4.783000 1.040000,4.834000 0.694000,4.871000 0.347000,4.893000 0.000000,4.900000 0.000000,4.400000 0.326000,4.393000 0.652000,4.373000 0.977000,4.338000 1.299000,4.290000 1.620000,4.229000 1.938000,4.154000 2.252000,4.066000 2.562000,3.964000 2.868000,3.850000 3.168000,3.723000 3.463000,3.583000 3.752000,3.431000 4.059000,3.270000 4.373000,3.121000 4.693000,2.986000 5.019000,2.864000 5.349000,2.756000 5.683000,2.662000 6.022000,2.582000 6.363000,2.517000 6.706000,2.466000 7.052000,2.429000 7.399000,2.407000 7.746000,2.400000 8.093000,2.407000 8.440000,2.429000 8.786000,2.466000 9.129000,2.517000 9.470000,2.582000 9.809000,2.662000 10.143000,2.756000 10.473000,2.864000 10.799000,2.986000 11.119000,3.121000 11.433000,3.270000 11.740000,3.431000 12.029000,3.583000 12.324000,3.723000 12.624000,3.850000 12.930000,3.964000 13.240000,4.066000 13.554000,4.154000 13.872000,4.229000 14.193000,4.290000 14.515000,4.338000 14.840000,4.373000 15.166000,4.393000 15.492000,4.400000 z" /><g transform="translate(15.492000 4.650000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(15.492000 0.000000) rotate(-180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 4.650000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section. A tuple with 2 values can be used, one for each coupler side.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Coupling Distance",
                    "name": "coupling_distance",
                    "tooltip": "Distance between bus and ring waveguide centers.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Radius",
                    "name": "radius",
                    "tooltip": "Central ring radius.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "S Bend Length",
                    "name": "s_bend_length",
                    "tooltip": "Length of the S bends.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "S Bend Offset",
                    "name": "s_bend_offset",
                    "tooltip": "Offset of the S bends.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bends that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "type": "number",
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                },
                {
                    "label": "Coupling Length",
                    "name": "coupling_length",
                    "tooltip": "Length of straigh coupling region.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.s_bend_ring_coupler",
            "label": "S Bend Ring Coupler",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-10.175000 -0.925000 20.350000 13.750000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.068750;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.068750;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.068750;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.068750;}.reference{fill:none;stroke:#221f20;stroke-width:0.048125;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.550000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.068750;}.dashed{stroke-dasharray:0.343750,0.206250;}.port{fill:none;stroke:#805080;stroke-width:0.137500;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.103125;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.275000 L 0.412500,0 0,0.275000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.206250 C 0.275000,-0.206250 0.275000,0.206250 0,0.206250" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.144375" /></defs><g transform="scale(1 -1)"><g id="s_bend_ring_coupler-0x56b8e5e08ec0"><path class="layer_1_0" d="M -7.746000,-11.900000 -7.357000,-11.892000 -6.968000,-11.867000 -6.580000,-11.826000 -6.195000,-11.769000 -5.813000,-11.696000 -5.433000,-11.606000 -5.058000,-11.501000 -4.688000,-11.380000 -4.323000,-11.244000 -3.965000,-11.092000 -3.613000,-10.925000 -3.268000,-10.744000 -3.016000,-10.611000 -2.759000,-10.490000 -2.498000,-10.379000 -2.231000,-10.279000 -1.961000,-10.191000 -1.688000,-10.114000 -1.411000,-10.049000 -1.132000,-9.996000 -0.851000,-9.954000 -0.568000,-9.924000 -0.284000,-9.906000 0.000000,-9.900000 0.284000,-9.906000 0.568000,-9.924000 0.851000,-9.954000 1.132000,-9.996000 1.411000,-10.049000 1.688000,-10.114000 1.961000,-10.191000 2.231000,-10.279000 2.498000,-10.379000 2.759000,-10.490000 3.016000,-10.611000 3.268000,-10.744000 3.613000,-10.925000 3.965000,-11.092000 4.323000,-11.244000 4.688000,-11.380000 5.058000,-11.501000 5.433000,-11.606000 5.813000,-11.696000 6.195000,-11.769000 6.580000,-11.826000 6.968000,-11.867000 7.357000,-11.892000 7.746000,-11.900000 7.746000,-9.400000 7.462000,-9.394000 7.178000,-9.376000 6.895000,-9.346000 6.614000,-9.304000 6.335000,-9.251000 6.058000,-9.186000 5.785000,-9.109000 5.515000,-9.021000 5.248000,-8.921000 4.987000,-8.810000 4.730000,-8.689000 4.478000,-8.556000 4.133000,-8.375000 3.781000,-8.208000 3.423000,-8.056000 3.058000,-7.920000 2.688000,-7.799000 2.313000,-7.694000 1.933000,-7.604000 1.551000,-7.531000 1.166000,-7.474000 0.778000,-7.433000 0.389000,-7.408000 0.000000,-7.400000 -0.389000,-7.408000 -0.778000,-7.433000 -1.166000,-7.474000 -1.551000,-7.531000 -1.933000,-7.604000 -2.313000,-7.694000 -2.688000,-7.799000 -3.058000,-7.920000 -3.423000,-8.056000 -3.781000,-8.208000 -4.133000,-8.375000 -4.478000,-8.556000 -4.730000,-8.689000 -4.987000,-8.810000 -5.248000,-8.921000 -5.515000,-9.021000 -5.785000,-9.109000 -6.058000,-9.186000 -6.335000,-9.251000 -6.614000,-9.304000 -6.895000,-9.346000 -7.178000,-9.376000 -7.462000,-9.394000 -7.746000,-9.400000 z" /><path class="layer_1_0" d="M 6.750000,0.000000 6.731000,-0.504000 6.708000,-0.756000 6.675000,-1.006000 6.581000,-1.502000 6.450000,-1.990000 6.283000,-2.466000 6.082000,-2.929000 5.846000,-3.375000 5.577000,-3.802000 5.277000,-4.209000 4.948000,-4.591000 4.591000,-4.948000 4.209000,-5.277000 3.802000,-5.577000 3.375000,-5.846000 2.929000,-6.082000 2.466000,-6.283000 1.990000,-6.450000 1.502000,-6.581000 1.006000,-6.675000 0.756000,-6.708000 0.252000,-6.745000 0.000000,-6.750000 -0.504000,-6.731000 -0.756000,-6.708000 -1.006000,-6.675000 -1.502000,-6.581000 -1.990000,-6.450000 -2.466000,-6.283000 -2.929000,-6.082000 -3.375000,-5.846000 -3.802000,-5.577000 -4.209000,-5.277000 -4.591000,-4.948000 -4.948000,-4.591000 -5.277000,-4.209000 -5.577000,-3.802000 -5.846000,-3.375000 -6.082000,-2.929000 -6.283000,-2.466000 -6.450000,-1.990000 -6.581000,-1.502000 -6.675000,-1.006000 -6.708000,-0.756000 -6.745000,-0.252000 -6.750000,0.000000 -9.250000,0.000000 -9.244000,-0.346000 -9.224000,-0.691000 -9.192000,-1.036000 -9.147000,-1.379000 -9.089000,-1.720000 -9.018000,-2.058000 -8.935000,-2.394000 -8.839000,-2.726000 -8.731000,-3.055000 -8.611000,-3.379000 -8.478000,-3.699000 -8.334000,-4.013000 -8.178000,-4.322000 -8.011000,-4.625000 -7.832000,-4.921000 -7.643000,-5.211000 -7.443000,-5.493000 -7.232000,-5.767000 -7.011000,-6.034000 -6.781000,-6.292000 -6.541000,-6.541000 -6.292000,-6.781000 -6.034000,-7.011000 -5.767000,-7.232000 -5.493000,-7.443000 -5.211000,-7.643000 -4.921000,-7.832000 -4.625000,-8.011000 -4.322000,-8.178000 -4.013000,-8.334000 -3.699000,-8.478000 -3.379000,-8.611000 -3.055000,-8.731000 -2.726000,-8.839000 -2.394000,-8.935000 -2.058000,-9.018000 -1.720000,-9.089000 -1.379000,-9.147000 -1.036000,-9.192000 -0.691000,-9.224000 -0.346000,-9.244000 0.000000,-9.250000 0.346000,-9.244000 0.691000,-9.224000 1.036000,-9.192000 1.379000,-9.147000 1.720000,-9.089000 2.058000,-9.018000 2.394000,-8.935000 2.726000,-8.839000 3.055000,-8.731000 3.379000,-8.611000 3.699000,-8.478000 4.013000,-8.334000 4.322000,-8.178000 4.625000,-8.011000 4.921000,-7.832000 5.211000,-7.643000 5.493000,-7.443000 5.767000,-7.232000 6.034000,-7.011000 6.292000,-6.781000 6.541000,-6.541000 6.781000,-6.292000 7.011000,-6.034000 7.232000,-5.767000 7.443000,-5.493000 7.643000,-5.211000 7.832000,-4.921000 8.011000,-4.625000 8.178000,-4.322000 8.334000,-4.013000 8.478000,-3.699000 8.611000,-3.379000 8.731000,-3.055000 8.839000,-2.726000 8.935000,-2.394000 9.018000,-2.058000 9.089000,-1.720000 9.147000,-1.379000 9.192000,-1.036000 9.224000,-0.691000 9.244000,-0.346000 9.250000,0.000000 z" /><path class="layer_2_0" d="M -7.746000,-10.900000 -7.399000,-10.893000 -7.052000,-10.871000 -6.706000,-10.834000 -6.363000,-10.783000 -6.022000,-10.718000 -5.683000,-10.638000 -5.349000,-10.544000 -5.019000,-10.436000 -4.693000,-10.314000 -4.373000,-10.179000 -4.059000,-10.031000 -3.752000,-9.869000 -3.463000,-9.717000 -3.168000,-9.577000 -2.868000,-9.450000 -2.562000,-9.336000 -2.252000,-9.234000 -1.938000,-9.146000 -1.620000,-9.071000 -1.299000,-9.010000 -0.977000,-8.962000 -0.652000,-8.927000 -0.326000,-8.907000 0.000000,-8.900000 0.326000,-8.907000 0.652000,-8.927000 0.977000,-8.962000 1.299000,-9.010000 1.620000,-9.071000 1.938000,-9.146000 2.252000,-9.234000 2.562000,-9.336000 2.868000,-9.450000 3.168000,-9.577000 3.463000,-9.717000 3.752000,-9.869000 4.059000,-10.031000 4.373000,-10.179000 4.693000,-10.314000 5.019000,-10.436000 5.349000,-10.544000 5.683000,-10.638000 6.022000,-10.718000 6.363000,-10.783000 6.706000,-10.834000 7.052000,-10.871000 7.399000,-10.893000 7.746000,-10.900000 7.746000,-10.400000 7.420000,-10.393000 7.094000,-10.373000 6.769000,-10.338000 6.447000,-10.290000 6.126000,-10.229000 5.808000,-10.154000 5.494000,-10.066000 5.184000,-9.964000 4.878000,-9.850000 4.578000,-9.723000 4.283000,-9.583000 3.994000,-9.431000 3.687000,-9.270000 3.373000,-9.121000 3.053000,-8.986000 2.727000,-8.864000 2.397000,-8.756000 2.063000,-8.662000 1.724000,-8.582000 1.383000,-8.517000 1.040000,-8.466000 0.694000,-8.429000 0.347000,-8.407000 0.000000,-8.400000 -0.347000,-8.407000 -0.694000,-8.429000 -1.040000,-8.466000 -1.383000,-8.517000 -1.724000,-8.582000 -2.063000,-8.662000 -2.397000,-8.756000 -2.727000,-8.864000 -3.053000,-8.986000 -3.373000,-9.121000 -3.687000,-9.270000 -3.994000,-9.431000 -4.283000,-9.583000 -4.578000,-9.723000 -4.878000,-9.850000 -5.184000,-9.964000 -5.494000,-10.066000 -5.808000,-10.154000 -6.126000,-10.229000 -6.447000,-10.290000 -6.769000,-10.338000 -7.094000,-10.373000 -7.420000,-10.393000 -7.746000,-10.400000 z" /><path class="layer_2_0" d="M 7.750000,0.000000 7.745000,-0.290000 7.701000,-0.868000 7.663000,-1.155000 7.615000,-1.441000 7.556000,-1.725000 7.486000,-2.006000 7.406000,-2.284000 7.315000,-2.560000 7.214000,-2.831000 6.983000,-3.363000 6.712000,-3.875000 6.562000,-4.123000 6.403000,-4.366000 6.236000,-4.602000 6.059000,-4.832000 5.874000,-5.055000 5.681000,-5.271000 5.480000,-5.480000 5.271000,-5.681000 5.055000,-5.874000 4.832000,-6.059000 4.602000,-6.236000 4.366000,-6.403000 4.123000,-6.562000 3.875000,-6.712000 3.363000,-6.983000 2.831000,-7.214000 2.560000,-7.315000 2.284000,-7.406000 2.006000,-7.486000 1.725000,-7.556000 1.441000,-7.615000 1.155000,-7.663000 0.868000,-7.701000 0.579000,-7.728000 0.290000,-7.745000 0.000000,-7.750000 -0.290000,-7.745000 -0.868000,-7.701000 -1.155000,-7.663000 -1.441000,-7.615000 -1.725000,-7.556000 -2.006000,-7.486000 -2.284000,-7.406000 -2.560000,-7.315000 -2.831000,-7.214000 -3.363000,-6.983000 -3.875000,-6.712000 -4.123000,-6.562000 -4.366000,-6.403000 -4.602000,-6.236000 -4.832000,-6.059000 -5.055000,-5.874000 -5.271000,-5.681000 -5.480000,-5.480000 -5.681000,-5.271000 -5.874000,-5.055000 -6.059000,-4.832000 -6.236000,-4.602000 -6.403000,-4.366000 -6.562000,-4.123000 -6.712000,-3.875000 -6.983000,-3.363000 -7.214000,-2.831000 -7.315000,-2.560000 -7.406000,-2.284000 -7.486000,-2.006000 -7.556000,-1.725000 -7.615000,-1.441000 -7.663000,-1.155000 -7.701000,-0.868000 -7.728000,-0.579000 -7.745000,-0.290000 -7.750000,0.000000 -8.250000,0.000000 -8.244000,-0.308000 -8.227000,-0.617000 -8.198000,-0.924000 -8.158000,-1.230000 -8.106000,-1.534000 -8.043000,-1.836000 -7.969000,-2.135000 -7.883000,-2.432000 -7.787000,-2.725000 -7.680000,-3.014000 -7.562000,-3.299000 -7.433000,-3.580000 -7.294000,-3.855000 -7.145000,-4.125000 -6.985000,-4.389000 -6.816000,-4.647000 -6.638000,-4.899000 -6.450000,-5.144000 -6.253000,-5.381000 -6.048000,-5.611000 -5.834000,-5.834000 -5.611000,-6.048000 -5.381000,-6.253000 -5.144000,-6.450000 -4.899000,-6.638000 -4.647000,-6.816000 -4.389000,-6.985000 -4.125000,-7.145000 -3.855000,-7.294000 -3.580000,-7.433000 -3.299000,-7.562000 -3.014000,-7.680000 -2.725000,-7.787000 -2.432000,-7.883000 -2.135000,-7.969000 -1.836000,-8.043000 -1.534000,-8.106000 -1.230000,-8.158000 -0.924000,-8.198000 -0.617000,-8.227000 -0.308000,-8.244000 0.000000,-8.250000 0.308000,-8.244000 0.617000,-8.227000 0.924000,-8.198000 1.230000,-8.158000 1.534000,-8.106000 1.836000,-8.043000 2.135000,-7.969000 2.432000,-7.883000 2.725000,-7.787000 3.014000,-7.680000 3.299000,-7.562000 3.580000,-7.433000 3.855000,-7.294000 4.125000,-7.145000 4.389000,-6.985000 4.647000,-6.816000 4.899000,-6.638000 5.144000,-6.450000 5.381000,-6.253000 5.611000,-6.048000 5.834000,-5.834000 6.048000,-5.611000 6.253000,-5.381000 6.450000,-5.144000 6.638000,-4.899000 6.816000,-4.647000 6.985000,-4.389000 7.145000,-4.125000 7.294000,-3.855000 7.433000,-3.580000 7.562000,-3.299000 7.680000,-3.014000 7.787000,-2.725000 7.883000,-2.432000 7.969000,-2.135000 8.043000,-1.836000 8.106000,-1.534000 8.158000,-1.230000 8.198000,-0.924000 8.227000,-0.617000 8.244000,-0.308000 8.250000,0.000000 z" /><g transform="translate(8.000000 0.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(7.746000 -10.650000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-8.000000 0.000000) rotate(-90.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(-7.746000 -10.650000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section. A tuple with 2 values can be used, one for each coupler side.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Coupling Distance",
                    "name": "coupling_distance",
                    "tooltip": "Distance between waveguide centers.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "S Bend Length",
                    "name": "s_bend_length",
                    "tooltip": "Length of the S bends.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "S Bend Offset",
                    "name": "s_bend_offset",
                    "tooltip": "Offset of the S bends.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "label": "Euler Fraction",
                    "name": "euler_fraction",
                    "tooltip": "Fraction of the bends that is created using an Euler spiral.",
                    "defaults": 0.0,
                    "type": "number",
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [0], "max": [1]},
                },
                {
                    "label": "Coupling Length",
                    "name": "coupling_length",
                    "tooltip": "Length of straigh coupling region.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.s_bend_straight_coupler",
            "label": "S Bend Straight Coupler",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-0.774600 -4.674600 17.041200 6.699200"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.033496;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.033496;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.033496;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.033496;}.reference{fill:none;stroke:#221f20;stroke-width:0.023447;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.267968px;}.terminal{fill:none;stroke:#805080;stroke-width:0.033496;}.dashed{stroke-dasharray:0.167480,0.100488;}.port{fill:none;stroke:#805080;stroke-width:0.066992;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.050244;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.133984 L 0.200976,0 0,0.133984" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.100488 C 0.133984,-0.100488 0.133984,0.100488 0,0.100488" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.070342" /></defs><g transform="scale(1 -1)"><g id="s_bend_straight_coupler-0x56b8e5e16ea0"><path class="layer_1_0" d="M 0.000000,-1.250000 15.492000,-1.250000 15.492000,1.250000 0.000000,1.250000 z" /><path class="layer_1_0" d="M 15.492000,3.900000 15.103000,3.892000 14.714000,3.867000 14.326000,3.826000 13.941000,3.769000 13.559000,3.696000 13.179000,3.606000 12.804000,3.501000 12.434000,3.380000 12.069000,3.244000 11.711000,3.092000 11.359000,2.925000 11.014000,2.744000 10.762000,2.611000 10.505000,2.490000 10.244000,2.379000 9.977000,2.279000 9.707000,2.191000 9.434000,2.114000 9.157000,2.049000 8.878000,1.996000 8.597000,1.954000 8.314000,1.924000 8.030000,1.906000 7.746000,1.900000 7.462000,1.906000 7.178000,1.924000 6.895000,1.954000 6.614000,1.996000 6.335000,2.049000 6.058000,2.114000 5.785000,2.191000 5.515000,2.279000 5.248000,2.379000 4.987000,2.490000 4.730000,2.611000 4.478000,2.744000 4.133000,2.925000 3.781000,3.092000 3.423000,3.244000 3.058000,3.380000 2.688000,3.501000 2.313000,3.606000 1.933000,3.696000 1.551000,3.769000 1.166000,3.826000 0.778000,3.867000 0.389000,3.892000 0.000000,3.900000 0.000000,1.400000 0.284000,1.394000 0.568000,1.376000 0.851000,1.346000 1.132000,1.304000 1.411000,1.251000 1.688000,1.186000 1.961000,1.109000 2.231000,1.021000 2.498000,0.921000 2.759000,0.810000 3.016000,0.689000 3.268000,0.556000 3.613000,0.375000 3.965000,0.208000 4.323000,0.056000 4.688000,-0.080000 5.058000,-0.201000 5.433000,-0.306000 5.813000,-0.396000 6.195000,-0.469000 6.580000,-0.526000 6.968000,-0.567000 7.357000,-0.592000 7.746000,-0.600000 8.135000,-0.592000 8.524000,-0.567000 8.912000,-0.526000 9.297000,-0.469000 9.679000,-0.396000 10.059000,-0.306000 10.434000,-0.201000 10.804000,-0.080000 11.169000,0.056000 11.527000,0.208000 11.879000,0.375000 12.224000,0.556000 12.476000,0.689000 12.733000,0.810000 12.994000,0.921000 13.261000,1.021000 13.531000,1.109000 13.804000,1.186000 14.081000,1.251000 14.360000,1.304000 14.641000,1.346000 14.924000,1.376000 15.208000,1.394000 15.492000,1.400000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 15.492000,-0.250000 15.492000,0.250000 0.000000,0.250000 z" /><path class="layer_2_0" d="M 15.492000,2.900000 15.145000,2.893000 14.798000,2.871000 14.452000,2.834000 14.109000,2.783000 13.768000,2.718000 13.429000,2.638000 13.095000,2.544000 12.765000,2.436000 12.439000,2.314000 12.119000,2.179000 11.805000,2.031000 11.498000,1.869000 11.209000,1.717000 10.914000,1.577000 10.614000,1.450000 10.308000,1.336000 9.998000,1.234000 9.684000,1.146000 9.366000,1.071000 9.045000,1.010000 8.723000,0.962000 8.398000,0.927000 8.072000,0.907000 7.746000,0.900000 7.420000,0.907000 7.094000,0.927000 6.769000,0.962000 6.447000,1.010000 6.126000,1.071000 5.808000,1.146000 5.494000,1.234000 5.184000,1.336000 4.878000,1.450000 4.578000,1.577000 4.283000,1.717000 3.994000,1.869000 3.687000,2.031000 3.373000,2.179000 3.053000,2.314000 2.727000,2.436000 2.397000,2.544000 2.063000,2.638000 1.724000,2.718000 1.383000,2.783000 1.040000,2.834000 0.694000,2.871000 0.347000,2.893000 0.000000,2.900000 0.000000,2.400000 0.326000,2.393000 0.652000,2.373000 0.977000,2.338000 1.299000,2.290000 1.620000,2.229000 1.938000,2.154000 2.252000,2.066000 2.562000,1.964000 2.868000,1.850000 3.168000,1.723000 3.463000,1.583000 3.752000,1.431000 4.059000,1.270000 4.373000,1.121000 4.693000,0.986000 5.019000,0.864000 5.349000,0.756000 5.683000,0.662000 6.022000,0.582000 6.363000,0.517000 6.706000,0.466000 7.052000,0.429000 7.399000,0.407000 7.746000,0.400000 8.093000,0.407000 8.440000,0.429000 8.786000,0.466000 9.129000,0.517000 9.470000,0.582000 9.809000,0.662000 10.143000,0.756000 10.473000,0.864000 10.799000,0.986000 11.119000,1.121000 11.433000,1.270000 11.740000,1.431000 12.029000,1.583000 12.324000,1.723000 12.624000,1.850000 12.930000,1.964000 13.240000,2.066000 13.554000,2.154000 13.872000,2.229000 14.193000,2.290000 14.515000,2.338000 14.840000,2.373000 15.166000,2.393000 15.492000,2.400000 z" /><g transform="translate(15.492000 2.650000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(15.492000 0.000000) rotate(-180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 2.650000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec",
                    "name": "port_spec",
                    "tooltip": "Port specification describing waveguide cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Length",
                    "name": "length",
                    "tooltip": "Section length.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Bulge Width",
                    "name": "bulge_width",
                    "tooltip": "Width added to the waveguide cross-section in the central region when ``length`` if enough to fit in 2 tapering sections plus margins.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Bulge Taper Length",
                    "name": "bulge_taper_length",
                    "tooltip": "Length of each tapering region for bulging the central region of the waveguide.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Bulge Margin",
                    "name": "bulge_margin",
                    "tooltip": "Length of the waveguide that must be kept without bulging at both ends.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.straight",
            "label": "Straight",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-0.400000 -1.650000 8.800000 3.300000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}.reference{fill:none;stroke:#221f20;stroke-width:0.011550;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.132000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.016500;}.dashed{stroke-dasharray:0.082500,0.049500;}.port{fill:none;stroke:#805080;stroke-width:0.033000;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.024750;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.066000 L 0.099000,0 0,0.066000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.049500 C 0.066000,-0.049500 0.066000,0.049500 0,0.049500" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.034650" /></defs><g transform="scale(1 -1)"><g id="straight-0x56b8e5e1c2e0"><path class="layer_1_0" d="M 0.000000,-1.250000 8.000000,-1.250000 8.000000,1.250000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 8.000000,-0.250000 8.000000,0.250000 0.000000,0.250000 z" /><g transform="translate(8.000000 0.000000) rotate(180.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
        {
            "arguments": [
                {
                    "label": "Port Spec1",
                    "name": "port_spec1",
                    "tooltip": "Port specification describing the first cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Port Spec2",
                    "name": "port_spec2",
                    "tooltip": "Port specification describing the second cross-section.",
                    "category": "portSpec",
                    "type": "select",
                },
                {
                    "label": "Length",
                    "name": "length",
                    "tooltip": "Transition length.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Constant Length",
                    "name": "constant_length",
                    "tooltip": "Constant cross-section length added to both ends.",
                    "defaults": 0.0,
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "label": "Profile",
                    "name": "profile",
                    "tooltip": 'String expression describing the transition shape parametrized by the independent variable ``"u"``, ranging from 0 to 1 along the transition. The expression must evaluate to a float between 0 and 1 representing the weight of the second profile with respect to the first at that position. Alternatively, an :class:`photonforge.Expression` with 1 parameter can be used.',
                    "type": "input",
                    "validates": ["expression"],
                    "validatesArgs": {"expression": [1]},
                },
                {
                    "name": "technology",
                    "placeholder": "Use the global default technology.",
                    "required": False,
                    "tooltip": "Component technology.",
                    "type": "technology",
                },
                {"name": "name", "required": False, "tooltip": "Component name.", "type": "input"},
            ],
            "function": "parametric.transition",
            "label": "Transition",
            "svg": '<?xml version="1.0" encoding="UTF-8"?><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" height="20.000000rem" viewBox="-0.400000 -1.650000 8.800000 3.300000"><style>path{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}rect{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}circle{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}ellipse{fill:#a3b8d6;stroke:#908f8f;stroke-width:0.016500;}.reference{fill:none;stroke:#221f20;stroke-width:0.011550;}.label{transform:scale(1,-1);fill:#221f20;font-weight:bold;font-size:0.132000px;}.terminal{fill:none;stroke:#805080;stroke-width:0.016500;}.dashed{stroke-dasharray:0.082500,0.049500;}.port{fill:none;stroke:#805080;stroke-width:0.033000;}.virtual-connection{fill:none;stroke:#907090;stroke-width:0.024750;}.layer_5_0{stroke:#b8a18b;fill:#b8a18b;fill-opacity:0.094;}.label_5_0{fill:#b8a18b;}.layer_4_0{stroke:#535e59;fill:#535e59;fill-opacity:0.094;}.label_4_0{fill:#535e59;}.layer_3_0{stroke:#8851ad;fill:#8851ad;fill-opacity:0.094;}.label_3_0{fill:#8851ad;}.layer_2_0{stroke:#6db5dd;fill:#6db5dd;fill-opacity:0.094;}.label_2_0{fill:#6db5dd;}.layer_1_0{stroke:#9da6a2;fill:#9da6a2;fill-opacity:0.094;}.label_1_0{fill:#9da6a2;}</style><defs><path id="port-symbol" class="port" d="M 0,-0.066000 L 0.099000,0 0,0.066000" /><path id="ref-port-symbol" class="port" style="stroke-opacity:0.33;" d="M 0,-0.049500 C 0.066000,-0.049500 0.066000,0.049500 0,0.049500" /><circle id="connection-symbol" style="stroke-width:0;stroke:none;fill:#907090;" cx="0" cy="0" r="0.034650" /></defs><g transform="scale(1 -1)"><g id="transition-0x56b8e5e1f980"><path class="layer_1_0" d="M 0.000000,-1.250000 1.600000,-1.240000 3.200000,-1.230000 4.800000,-1.220000 6.400000,-1.210000 8.000000,-1.200000 8.000000,1.200000 6.400000,1.210000 4.800000,1.220000 3.200000,1.230000 1.600000,1.240000 0.000000,1.250000 z" /><path class="layer_2_0" d="M 0.000000,-0.250000 1.600000,-0.240000 3.200000,-0.230000 4.800000,-0.220000 6.400000,-0.210000 8.000000,-0.200000 8.000000,0.200000 6.400000,0.210000 4.800000,0.220000 3.200000,0.230000 1.600000,0.240000 0.000000,0.250000 z" /><path class="layer_3_0" d="M 0.000000,0.000000 1.600000,-0.240000 3.200000,-0.480000 4.800000,-0.720000 6.400000,-0.960000 8.000000,-1.200000 8.000000,1.200000 6.400000,0.960000 4.800000,0.720000 3.200000,0.480000 1.600000,0.240000 z" /><g transform="translate(8.000000 0.000000) rotate(180.000000)"><path class="port" d="M 0,-1.080000 V 1.080000" /><use href="#port-symbol" /></g><g transform="translate(0.000000 0.000000) rotate(0.000000)"><path class="port" d="M 0,-1.125000 V 1.125000" /><use href="#port-symbol" /></g></g></g></svg>',
        },
    ],
    "technologies": [
        {
            "arguments": [
                {
                    "itemSpan": 24,
                    "label": "Core Medium",
                    "name": "core_medium",
                    "tooltip": "Medium used for the core layer.",
                    "type": "subForm",
                    "children": [
                        {
                            "type": "medium",
                            "name": "optical",
                            "hideLabel": True,
                            "prefix": "Optical",
                            "defaults": {
                                "type": "material_library",
                                "value": {"path": ["cSi", "Li1993_293K"]},
                            },
                        },
                        {
                            "type": "medium",
                            "name": "electrical",
                            "hideLabel": True,
                            "prefix": "Electrical",
                            "defaults": {
                                "type": "constructor",
                                "value": {"type": "Medium", "permittivity": 12.3},
                            },
                        },
                    ],
                },
                {
                    "itemSpan": 24,
                    "label": "Clad Medium",
                    "name": "clad_medium",
                    "tooltip": "Medium used for cladding.",
                    "type": "subForm",
                    "children": [
                        {
                            "type": "medium",
                            "name": "optical",
                            "hideLabel": True,
                            "prefix": "Optical",
                            "defaults": {
                                "type": "material_library",
                                "value": {"path": ["SiO2", "Palik_Lossless"]},
                            },
                        },
                        {
                            "type": "medium",
                            "name": "electrical",
                            "hideLabel": True,
                            "prefix": "Electrical",
                            "defaults": {
                                "type": "constructor",
                                "value": {"type": "Medium", "permittivity": 4.2},
                            },
                        },
                    ],
                },
                {
                    "itemSpan": 24,
                    "label": "Trench Medium",
                    "name": "trench_medium",
                    "tooltip": "Medium used for trenches.",
                    "type": "subForm",
                    "children": [
                        {
                            "type": "medium",
                            "name": "optical",
                            "hideLabel": True,
                            "prefix": "Optical",
                            "defaults": {"type": "constructor", "value": {"type": "Medium"}},
                        },
                        {
                            "type": "medium",
                            "name": "electrical",
                            "hideLabel": True,
                            "prefix": "Electrical",
                            "defaults": {"type": "constructor", "value": {"type": "Medium"}},
                        },
                    ],
                },
                {
                    "itemSpan": 24,
                    "label": "Metal Medium",
                    "name": "metal_medium",
                    "tooltip": "Medium used for the metal layer.",
                    "type": "subForm",
                    "children": [
                        {
                            "type": "medium",
                            "name": "optical",
                            "hideLabel": True,
                            "prefix": "Optical",
                            "defaults": {
                                "type": "material_library",
                                "value": {"path": ["Cu", "JohnsonChristy1972"]},
                            },
                        },
                        {
                            "type": "medium",
                            "name": "electrical",
                            "hideLabel": True,
                            "prefix": "Electrical",
                            "defaults": {
                                "type": "constructor",
                                "value": {"type": "PECMedium", "name": "PEC"},
                            },
                        },
                    ],
                },
                {
                    "itemSpan": 24,
                    "label": "Top Medium",
                    "name": "top_medium",
                    "tooltip": "If set, an infinite layer above the clad is added with this medium.",
                    "type": "subForm",
                    "children": [
                        {
                            "type": "medium",
                            "name": "optical",
                            "hideLabel": True,
                            "prefix": "Optical",
                        },
                        {
                            "type": "medium",
                            "name": "electrical",
                            "hideLabel": True,
                            "prefix": "Electrical",
                        },
                    ],
                },
                {
                    "itemSpan": 24,
                    "label": "Substrate Medium",
                    "name": "substrate_medium",
                    "tooltip": "If set, an infinite layer bellow the bottom clad is added with this medium.",
                    "type": "subForm",
                    "children": [
                        {
                            "type": "medium",
                            "name": "optical",
                            "hideLabel": True,
                            "prefix": "Optical",
                        },
                        {
                            "type": "medium",
                            "name": "electrical",
                            "hideLabel": True,
                            "prefix": "Electrical",
                        },
                    ],
                },
                {
                    "defaults": 0.22,
                    "label": "Core Thickness",
                    "name": "core_thickness",
                    "tooltip": "Thickness of the core layer.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 0.07,
                    "label": "Slab Thickness",
                    "name": "slab_thickness",
                    "tooltip": "Thickness of the slab region (partially etched core thickness).",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 0.5,
                    "label": "Metal Thickness",
                    "name": "metal_thickness",
                    "tooltip": "Thickness of the metal layer.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 1.5,
                    "label": "Metal Separation",
                    "name": "metal_separation",
                    "tooltip": "Distance between the top of the silicon layer and the bottom of the metal layer.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 1.0,
                    "label": "Clad Thickness",
                    "name": "clad_thickness",
                    "tooltip": "Top cladding thickness.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 1.0,
                    "label": "BOX Thickness",
                    "name": "box_thickness",
                    "tooltip": "Bottom cladding thickness.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": (2, 0),
                    "label": "Core Layer",
                    "name": "core_layer",
                    "tooltip": "Layer tuple for the core region.",
                    "type": "input",
                    "validates": ["regexp"],
                    "validatesArgs": {"regexp": ["LayerRexexp"]},
                },
                {
                    "defaults": (3, 0),
                    "label": "Slab Layer",
                    "name": "slab_layer",
                    "tooltip": "Layer tuple for the slab region.",
                    "type": "input",
                    "validates": ["regexp"],
                    "validatesArgs": {"regexp": ["LayerRexexp"]},
                },
                {
                    "defaults": (1, 0),
                    "label": "Clad Layer",
                    "name": "clad_layer",
                    "tooltip": "Layer tuple for the clad region.",
                    "type": "input",
                    "validates": ["regexp"],
                    "validatesArgs": {"regexp": ["LayerRexexp"]},
                },
                {
                    "defaults": (4, 0),
                    "label": "Trench Layer",
                    "name": "trench_layer",
                    "tooltip": "Layer tuple for the trench region.",
                    "type": "input",
                    "validates": ["regexp"],
                    "validatesArgs": {"regexp": ["LayerRexexp"]},
                },
                {
                    "defaults": (5, 0),
                    "label": "Metal Layer",
                    "name": "metal_layer",
                    "tooltip": "Layer tuple for the metal region.",
                    "type": "input",
                    "validates": ["regexp"],
                    "validatesArgs": {"regexp": ["LayerRexexp"]},
                },
                {
                    "defaults": 0.5,
                    "label": "Strip Width",
                    "name": "strip_width",
                    "tooltip": "Strip waveguide core width.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "defaults": 0.4,
                    "label": "Rib Width",
                    "name": "rib_width",
                    "tooltip": "Rib waveguide core width.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "defaults": 1.0,
                    "label": "Clad Width",
                    "name": "clad_width",
                    "tooltip": "Cladding width to the sides of waveguides.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "defaults": 3.6,
                    "label": "CPW Width",
                    "name": "cpw_width",
                    "tooltip": "Width of the central conductor for the CPW transmission line in the metal layer.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "defaults": 2.5,
                    "label": "CPW Gap",
                    "name": "cpw_gap",
                    "tooltip": "Spacing betwee the central conductor and the ground pads for the CPW transmission line in the metal layer.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 5.0,
                    "label": "CPW Refinement",
                    "name": "cpw_refinement",
                    "tooltip": "Mesh refinement around the CPW gaps.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "defaults": 0,
                    "label": "Mask Dilation",
                    "name": "mask_dilation",
                    "tooltip": "Dilation appplied to the core extrusion masks.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "defaults": 0,
                    "label": "Sidewall Angle",
                    "name": "sidewall_angle",
                    "tooltip": "Etching angle in the core (in degrees).",
                    "type": "number",
                    "suffix": "°",
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [-90], "max": [90]},
                },
                {
                    "defaults": False,
                    "label": "Core Fill",
                    "name": "core_fill",
                    "tooltip": "If set, device bounds will be filled with the core layer and only cladding and slab regions will have it (partially) removed. Otherwise, only core and slab regions will have the core medium.",
                    "type": "checkbox",
                },
                {
                    "defaults": 0.002,
                    "label": "Core Thickness Stdev",
                    "name": "core_thickness_stdev",
                    "tooltip": "Standard deviation for core_thickness.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 0.005,
                    "label": "Slab Thickness Stdev",
                    "name": "slab_thickness_stdev",
                    "tooltip": "Standard deviation for core_thickness.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 0.05,
                    "label": "Clad Thickness Stdev",
                    "name": "clad_thickness_stdev",
                    "tooltip": "Standard deviation for core_thickness.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 0.05,
                    "label": "BOX Thickness Stdev",
                    "name": "box_thickness_stdev",
                    "tooltip": "Standard deviation for core_thickness.",
                    "type": "number",
                    "suffix": "μm",
                    "validates": ["min"],
                    "validatesArgs": {"min": [0]},
                },
                {
                    "defaults": 0.005,
                    "label": "Mask Dilation Stdev",
                    "name": "mask_dilation_stdev",
                    "tooltip": "Standard deviation for mask_dilation.",
                    "type": "number",
                    "suffix": "μm",
                },
                {
                    "defaults": 2,
                    "label": "Sidewall Angle Stdev",
                    "name": "sidewall_angle_stdev",
                    "tooltip": "Standard deviation for sidewall angle (in degrees).",
                    "type": "number",
                    "suffix": "°",
                    "validates": ["min", "max"],
                    "validatesArgs": {"min": [-90], "max": [90]},
                },
            ],
            "function": "basic_technology",
            "label": "Basic Technology",
        }
    ],
}
